@@ -1,10 +1,11 @@
 // An exception thrown from a proxy trap while getting the .iterator method is propagated.
 
 load(libdir + "asserts.js");
+load(libdir + "iteration.js");
 
 var p = Proxy.create({
     getPropertyDescriptor: function (name) {
-        if (name == "iterator")
+        if (name == Symbol.iterator)
             throw "fit";
         return undefined;
     }
