@@ -1,10 +1,10 @@
 /* Exercise the path where we want to collect a new compartment in the middle of incremental GC. */
 
-var g1 = newGlobal('new-compartment');
-var g2 = newGlobal('new-compartment');
+var g1 = newGlobal();
+var g2 = newGlobal();
 
 schedulegc(g1);
-gcslice(0);
+gcslice(0); // Start IGC, but don't mark anything.
 schedulegc(g2);
 gcslice(1);
 gcslice();
