@@ -10,7 +10,7 @@
 
 #include "jit/Bailouts.h"
 #include "jit/BaselineFrame.h"
-#include "jit/IonFrames.h"
+#include "jit/JitFrames.h"
 #include "jit/MoveEmitter.h"
 
 #include "jsscriptinlines.h"
@@ -18,7 +18,7 @@
 using namespace js;
 using namespace js::jit;
 
-MacroAssemblerX86::Double *
+MacroAssemblerX86::Double*
 MacroAssemblerX86::getDouble(double d)
 {
     if (!doubleMap_.initialized()) {
@@ -37,34 +37,34 @@ MacroAssemblerX86::getDouble(double d)
         if (!enoughMemory_)
             return nullptr;
     }
-    Double &dbl = doubles_[doubleIndex];
-    JS_ASSERT(!dbl.uses.bound());
+    Double& dbl = doubles_[doubleIndex];
+    MOZ_ASSERT(!dbl.uses.bound());
     return &dbl;
 }
 
 void
-MacroAssemblerX86::loadConstantDouble(double d, const FloatRegister &dest)
+MacroAssemblerX86::loadConstantDouble(double d, FloatRegister dest)
 {
     if (maybeInlineDouble(d, dest))
         return;
-    Double *dbl = getDouble(d);
+    Double* dbl = getDouble(d);
     if (!dbl)
         return;
-    masm.movsd_mr(reinterpret_cast<const void *>(dbl->uses.prev()), dest.code());
+    masm.vmovsd_mr(reinterpret_cast<const void*>(dbl->uses.prev()), dest.code());
     dbl->uses.setPrev(masm.size());
 }
 
 void
-MacroAssemblerX86::addConstantDouble(double d, const FloatRegister &dest)
+MacroAssemblerX86::addConstantDouble(double d, FloatRegister dest)
 {
-    Double *dbl = getDouble(d);
+    Double* dbl = getDouble(d);
     if (!dbl)
         return;
-    masm.addsd_mr(reinterpret_cast<const void *>(dbl->uses.prev()), dest.code());
+    masm.vaddsd_mr(reinterpret_cast<const void*>(dbl->uses.prev()), dest.code(), dest.code());
     dbl->uses.setPrev(masm.size());
 }
 
-MacroAssemblerX86::Float *
+MacroAssemblerX86::Float*
 MacroAssemblerX86::getFloat(float f)
 {
     if (!floatMap_.initialized()) {
@@ -83,33 +83,85 @@ MacroAssemblerX86::getFloat(float f)
         if (!enoughMemory_)
             return nullptr;
     }
-    Float &flt = floats_[floatIndex];
-    JS_ASSERT(!flt.uses.bound());
+    Float& flt = floats_[floatIndex];
+    MOZ_ASSERT(!flt.uses.bound());
     return &flt;
 }
 
 void
-MacroAssemblerX86::loadConstantFloat32(float f, const FloatRegister &dest)
+MacroAssemblerX86::loadConstantFloat32(float f, FloatRegister dest)
 {
     if (maybeInlineFloat(f, dest))
         return;
-    Float *flt = getFloat(f);
+    Float* flt = getFloat(f);
     if (!flt)
         return;
-    masm.movss_mr(reinterpret_cast<const void *>(flt->uses.prev()), dest.code());
+    masm.vmovss_mr(reinterpret_cast<const void*>(flt->uses.prev()), dest.code());
     flt->uses.setPrev(masm.size());
 }
 
 void
-MacroAssemblerX86::addConstantFloat32(float f, const FloatRegister &dest)
+MacroAssemblerX86::addConstantFloat32(float f, FloatRegister dest)
 {
-    Float *flt = getFloat(f);
+    Float* flt = getFloat(f);
     if (!flt)
         return;
-    masm.addss_mr(reinterpret_cast<const void *>(flt->uses.prev()), dest.code());
+    masm.vaddss_mr(reinterpret_cast<const void*>(flt->uses.prev()), dest.code(), dest.code());
     flt->uses.setPrev(masm.size());
 }
 
+MacroAssemblerX86::SimdData*
+MacroAssemblerX86::getSimdData(const SimdConstant& v)
+{
+    if (!simdMap_.initialized()) {
+        enoughMemory_ &= simdMap_.init();
+        if (!enoughMemory_)
+            return nullptr;
+    }
+    size_t index;
+    SimdMap::AddPtr p = simdMap_.lookupForAdd(v);
+    if (p) {
+        index = p->value();
+    } else {
+        index = simds_.length();
+        enoughMemory_ &= simds_.append(SimdData(v));
+        enoughMemory_ &= simdMap_.add(p, v, index);
+        if (!enoughMemory_)
+            return nullptr;
+    }
+    SimdData& simd = simds_[index];
+    MOZ_ASSERT(!simd.uses.bound());
+    return &simd;
+}
+
+void
+MacroAssemblerX86::loadConstantInt32x4(const SimdConstant& v, FloatRegister dest)
+{
+    MOZ_ASSERT(v.type() == SimdConstant::Int32x4);
+    if (maybeInlineInt32x4(v, dest))
+        return;
+    SimdData* i4 = getSimdData(v);
+    if (!i4)
+        return;
+    MOZ_ASSERT(i4->type() == SimdConstant::Int32x4);
+    masm.vmovdqa_mr(reinterpret_cast<const void*>(i4->uses.prev()), dest.code());
+    i4->uses.setPrev(masm.size());
+}
+
+void
+MacroAssemblerX86::loadConstantFloat32x4(const SimdConstant& v, FloatRegister dest)
+{
+    MOZ_ASSERT(v.type() == SimdConstant::Float32x4);
+    if (maybeInlineFloat32x4(v, dest))
+        return;
+    SimdData* f4 = getSimdData(v);
+    if (!f4)
+        return;
+    MOZ_ASSERT(f4->type() == SimdConstant::Float32x4);
+    masm.vmovaps_mr(reinterpret_cast<const void*>(f4->uses.prev()), dest.code());
+    f4->uses.setPrev(masm.size());
+}
+
 void
 MacroAssemblerX86::finish()
 {
@@ -118,7 +170,7 @@ MacroAssemblerX86::finish()
     for (size_t i = 0; i < doubles_.length(); i++) {
         CodeLabel cl(doubles_[i].uses);
         writeDoubleConstant(doubles_[i].value, cl.src());
-        enoughMemory_ &= addCodeLabel(cl);
+        addCodeLabel(cl);
         if (!enoughMemory_)
             return;
     }
@@ -128,7 +180,23 @@ MacroAssemblerX86::finish()
     for (size_t i = 0; i < floats_.length(); i++) {
         CodeLabel cl(floats_[i].uses);
         writeFloatConstant(floats_[i].value, cl.src());
-        enoughMemory_ &= addCodeLabel(cl);
+        addCodeLabel(cl);
+        if (!enoughMemory_)
+            return;
+    }
+
+    // SIMD memory values must be suitably aligned.
+    if (!simds_.empty())
+        masm.align(SimdMemoryAlignment);
+    for (size_t i = 0; i < simds_.length(); i++) {
+        CodeLabel cl(simds_[i].uses);
+        SimdData& v = simds_[i];
+        switch (v.type()) {
+          case SimdConstant::Int32x4:   writeInt32x4Constant(v.value, cl.src());   break;
+          case SimdConstant::Float32x4: writeFloat32x4Constant(v.value, cl.src()); break;
+          default: MOZ_CRASH("unexpected SimdConstant type");
+        }
+        addCodeLabel(cl);
         if (!enoughMemory_)
             return;
     }
@@ -137,7 +205,7 @@ MacroAssemblerX86::finish()
 void
 MacroAssemblerX86::setupABICall(uint32_t args)
 {
-    JS_ASSERT(!inCall_);
+    MOZ_ASSERT(!inCall_);
     inCall_ = true;
 
     args_ = args;
@@ -153,18 +221,18 @@ MacroAssemblerX86::setupAlignedABICall(uint32_t args)
 }
 
 void
-MacroAssemblerX86::setupUnalignedABICall(uint32_t args, const Register &scratch)
+MacroAssemblerX86::setupUnalignedABICall(uint32_t args, Register scratch)
 {
     setupABICall(args);
     dynamicAlignment_ = true;
 
     movl(esp, scratch);
-    andl(Imm32(~(StackAlignment - 1)), esp);
+    andl(Imm32(~(ABIStackAlignment - 1)), esp);
     push(scratch);
 }
 
 void
-MacroAssemblerX86::passABIArg(const MoveOperand &from, MoveOp::Type type)
+MacroAssemblerX86::passABIArg(const MoveOperand& from, MoveOp::Type type)
 {
     ++passedArgs_;
     MoveOperand to = MoveOperand(StackPointer, stackForCall_);
@@ -173,37 +241,37 @@ MacroAssemblerX86::passABIArg(const MoveOperand &from, MoveOp::Type type)
       case MoveOp::DOUBLE:  stackForCall_ += sizeof(double); break;
       case MoveOp::INT32:   stackForCall_ += sizeof(int32_t); break;
       case MoveOp::GENERAL: stackForCall_ += sizeof(intptr_t); break;
-      default: MOZ_ASSUME_UNREACHABLE("Unexpected argument type");
+      default: MOZ_CRASH("Unexpected argument type");
     }
     enoughMemory_ &= moveResolver_.addMove(from, to, type);
 }
 
 void
-MacroAssemblerX86::passABIArg(const Register &reg)
+MacroAssemblerX86::passABIArg(Register reg)
 {
     passABIArg(MoveOperand(reg), MoveOp::GENERAL);
 }
 
 void
-MacroAssemblerX86::passABIArg(const FloatRegister &reg, MoveOp::Type type)
+MacroAssemblerX86::passABIArg(FloatRegister reg, MoveOp::Type type)
 {
     passABIArg(MoveOperand(reg), type);
 }
 
 void
-MacroAssemblerX86::callWithABIPre(uint32_t *stackAdjust)
+MacroAssemblerX86::callWithABIPre(uint32_t* stackAdjust)
 {
-    JS_ASSERT(inCall_);
-    JS_ASSERT(args_ == passedArgs_);
+    MOZ_ASSERT(inCall_);
+    MOZ_ASSERT(args_ == passedArgs_);
 
     if (dynamicAlignment_) {
         *stackAdjust = stackForCall_
                      + ComputeByteAlignment(stackForCall_ + sizeof(intptr_t),
-                                            StackAlignment);
+                                            ABIStackAlignment);
     } else {
         *stackAdjust = stackForCall_
                      + ComputeByteAlignment(stackForCall_ + framePushed_,
-                                            StackAlignment);
+                                            ABIStackAlignment);
     }
 
     reserveStack(*stackAdjust);
@@ -223,7 +291,7 @@ MacroAssemblerX86::callWithABIPre(uint32_t *stackAdjust)
     {
         // Check call alignment.
         Label good;
-        testl(esp, Imm32(StackAlignment - 1));
+        test32(esp, Imm32(ABIStackAlignment - 1));
         j(Equal, &good);
         breakpoint();
         bind(&good);
@@ -238,23 +306,23 @@ MacroAssemblerX86::callWithABIPost(uint32_t stackAdjust, MoveOp::Type result)
     if (result == MoveOp::DOUBLE) {
         reserveStack(sizeof(double));
         fstp(Operand(esp, 0));
-        loadDouble(Operand(esp, 0), ReturnFloatReg);
+        loadDouble(Operand(esp, 0), ReturnDoubleReg);
         freeStack(sizeof(double));
     } else if (result == MoveOp::FLOAT32) {
         reserveStack(sizeof(float));
         fstp32(Operand(esp, 0));
-        loadFloat32(Operand(esp, 0), ReturnFloatReg);
+        loadFloat32(Operand(esp, 0), ReturnFloat32Reg);
         freeStack(sizeof(float));
     }
     if (dynamicAlignment_)
         pop(esp);
 
-    JS_ASSERT(inCall_);
+    MOZ_ASSERT(inCall_);
     inCall_ = false;
 }
 
 void
-MacroAssemblerX86::callWithABI(void *fun, MoveOp::Type result)
+MacroAssemblerX86::callWithABI(void* fun, MoveOp::Type result)
 {
     uint32_t stackAdjust;
     callWithABIPre(&stackAdjust);
@@ -272,7 +340,7 @@ MacroAssemblerX86::callWithABI(AsmJSImmPtr fun, MoveOp::Type result)
 }
 
 void
-MacroAssemblerX86::callWithABI(const Address &fun, MoveOp::Type result)
+MacroAssemblerX86::callWithABI(const Address& fun, MoveOp::Type result)
 {
     uint32_t stackAdjust;
     callWithABIPre(&stackAdjust);
@@ -281,24 +349,26 @@ MacroAssemblerX86::callWithABI(const Address &fun, MoveOp::Type result)
 }
 
 void
-MacroAssemblerX86::handleFailureWithHandler(void *handler)
+MacroAssemblerX86::callWithABI(Register fun, MoveOp::Type result)
+{
+    uint32_t stackAdjust;
+    callWithABIPre(&stackAdjust);
+    call(Operand(fun));
+    callWithABIPost(stackAdjust, result);
+}
+
+void
+MacroAssemblerX86::handleFailureWithHandlerTail(void* handler)
 {
     // Reserve space for exception information.
     subl(Imm32(sizeof(ResumeFromException)), esp);
     movl(esp, eax);
 
-    // Ask for an exception handler.
+    // Call the handler.
     setupUnalignedABICall(1, ecx);
     passABIArg(eax);
     callWithABI(handler);
 
-    JitCode *excTail = GetIonContext()->runtime->jitRuntime()->getExceptionTail();
-    jmp(excTail);
-}
-
-void
-MacroAssemblerX86::handleFailureWithHandlerTail()
-{
     Label entryFrame;
     Label catch_;
     Label finally;
@@ -351,6 +421,18 @@ MacroAssemblerX86::handleFailureWithHandlerTail()
     loadValue(Address(ebp, BaselineFrame::reverseOffsetOfReturnValue()), JSReturnOperand);
     movl(ebp, esp);
     pop(ebp);
+
+    // If profiling is enabled, then update the lastProfilingFrame to refer to caller
+    // frame before returning.
+    {
+        Label skipProfilingInstrumentation;
+        // Test if profiler enabled.
+        AbsoluteAddress addressOfEnabled(GetJitContext()->runtime->spsProfiler().addressOfEnabled());
+        branch32(Assembler::Equal, addressOfEnabled, Imm32(0), &skipProfilingInstrumentation);
+        profilerExitFrame();
+        bind(&skipProfilingInstrumentation);
+    }
+
     ret();
 
     // If we are bailing out to baseline to handle an exception, jump to
@@ -362,54 +444,100 @@ MacroAssemblerX86::handleFailureWithHandlerTail()
 }
 
 void
-MacroAssemblerX86::branchTestValue(Condition cond, const ValueOperand &value, const Value &v, Label *label)
+MacroAssemblerX86::branchTestValue(Condition cond, const ValueOperand& value, const Value& v, Label* label)
 {
     jsval_layout jv = JSVAL_TO_IMPL(v);
     if (v.isMarkable())
-        cmpl(value.payloadReg(), ImmGCPtr(reinterpret_cast<gc::Cell *>(v.toGCThing())));
+        cmpPtr(value.payloadReg(), ImmGCPtr(reinterpret_cast<gc::Cell*>(v.toGCThing())));
     else
-        cmpl(value.payloadReg(), Imm32(jv.s.payload.i32));
+        cmpPtr(value.payloadReg(), ImmWord(jv.s.payload.i32));
 
     if (cond == Equal) {
         Label done;
         j(NotEqual, &done);
         {
-            cmpl(value.typeReg(), Imm32(jv.s.tag));
+            cmp32(value.typeReg(), Imm32(jv.s.tag));
             j(Equal, label);
         }
         bind(&done);
     } else {
-        JS_ASSERT(cond == NotEqual);
+        MOZ_ASSERT(cond == NotEqual);
         j(NotEqual, label);
 
-        cmpl(value.typeReg(), Imm32(jv.s.tag));
+        cmp32(value.typeReg(), Imm32(jv.s.tag));
         j(NotEqual, label);
     }
 }
 
-#ifdef JSGC_GENERATIONAL
+template <typename T>
+void
+MacroAssemblerX86::storeUnboxedValue(ConstantOrRegister value, MIRType valueType, const T& dest,
+                                     MIRType slotType)
+{
+    if (valueType == MIRType_Double) {
+        storeDouble(value.reg().typedReg().fpu(), dest);
+        return;
+    }
+
+    // Store the type tag if needed.
+    if (valueType != slotType)
+        storeTypeTag(ImmType(ValueTypeFromMIRType(valueType)), Operand(dest));
+
+    // Store the payload.
+    if (value.constant())
+        storePayload(value.value(), Operand(dest));
+    else
+        storePayload(value.reg().typedReg().gpr(), Operand(dest));
+}
+
+template void
+MacroAssemblerX86::storeUnboxedValue(ConstantOrRegister value, MIRType valueType, const Address& dest,
+                                     MIRType slotType);
+
+template void
+MacroAssemblerX86::storeUnboxedValue(ConstantOrRegister value, MIRType valueType, const BaseIndex& dest,
+                                     MIRType slotType);
 
 void
-MacroAssemblerX86::branchPtrInNurseryRange(Register ptr, Register temp, Label *label)
+MacroAssemblerX86::branchPtrInNurseryRange(Condition cond, Register ptr, Register temp,
+                                           Label* label)
 {
-    JS_ASSERT(ptr != temp);
-    JS_ASSERT(temp != InvalidReg);  // A temp register is required for x86.
+    MOZ_ASSERT(cond == Assembler::Equal || cond == Assembler::NotEqual);
+    MOZ_ASSERT(ptr != temp);
+    MOZ_ASSERT(temp != InvalidReg);  // A temp register is required for x86.
 
-    const Nursery &nursery = GetIonContext()->runtime->gcNursery();
+    const Nursery& nursery = GetJitContext()->runtime->gcNursery();
     movePtr(ImmWord(-ptrdiff_t(nursery.start())), temp);
     addPtr(ptr, temp);
-    branchPtr(Assembler::Below, temp, Imm32(Nursery::NurserySize), label);
+    branchPtr(cond == Assembler::Equal ? Assembler::Below : Assembler::AboveOrEqual,
+              temp, Imm32(nursery.nurserySize()), label);
 }
 
 void
-MacroAssemblerX86::branchValueIsNurseryObject(ValueOperand value, Register temp, Label *label)
+MacroAssemblerX86::branchValueIsNurseryObject(Condition cond, ValueOperand value, Register temp,
+                                              Label* label)
 {
+    MOZ_ASSERT(cond == Assembler::Equal || cond == Assembler::NotEqual);
+
     Label done;
 
-    branchTestObject(Assembler::NotEqual, value, &done);
-    branchPtrInNurseryRange(value.payloadReg(), temp, label);
+    branchTestObject(Assembler::NotEqual, value, cond == Assembler::Equal ? &done : label);
+    branchPtrInNurseryRange(cond, value.payloadReg(), temp, label);
 
     bind(&done);
 }
 
-#endif
+void
+MacroAssemblerX86::profilerEnterFrame(Register framePtr, Register scratch)
+{
+    AbsoluteAddress activation(GetJitContext()->runtime->addressOfProfilingActivation());
+    loadPtr(activation, scratch);
+    storePtr(framePtr, Address(scratch, JitActivation::offsetOfLastProfilingFrame()));
+    storePtr(ImmPtr(nullptr), Address(scratch, JitActivation::offsetOfLastProfilingCallSite()));
+}
+
+void
+MacroAssemblerX86::profilerExitFrame()
+{
+    jmp(GetJitContext()->runtime->jitRuntime()->getProfilerExitFrameTail());
+}
