@@ -12,22 +12,31 @@ var expect = '';
 printBugNumber(BUGNUMBER);
 printStatus (summary);
 
-var str_with_num = "0.1";
+var str = "test";
 
-var obj = {
-  get elem() {
-    return str_with_num;
-  },
-  set elem(value) {
-    gc();
+var lval = {
+  valueOf: function() {
+    return str+"1";
   }
-
 };
 
-expect = Number(str_with_num);
-actual = obj.elem++;
+var ONE = 1;
 
-gc();
+var rval = {
+  valueOf: function() {
+    // Make sure that the result of the previous lval.valueOf
+    // is not GC-rooted.
+    var tmp = "x"+lval;
+    if (typeof gc == "function")
+      gc();
+    for (var i = 0; i != 40000; ++i) {
+      tmp = 1e100 / ONE;
+    }
+    return str;
+  }
+};
+
+expect = (str+"1" > str);
+actual = (lval > rval);
 
- 
 reportCompare(expect, actual, summary);
