@@ -4,8 +4,8 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 456540;
-var summary = 'Do not assert with JIT: (m != JSVAL_INT) || isInt32(*vp)" with ((-1) % ""';
+var BUGNUMBER = 456477;
+var summary = 'Do not assert with JIT: (m != JSVAL_INT) || isInt32(*vp)" with (0/0)%(-1)';
 var actual = 'No Crash';
 var expect = 'No Crash';
 
@@ -22,7 +22,7 @@ function test()
  
   jit(true);
 
-  for (var j = 0; j < 5; ++j) { var t = ((-1) % "" ); }
+  for (var j = 0; j < 5; ++j) { var t = (0 / 0) % (-1); }
 
   jit(false);
 
