@@ -4,14 +4,29 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 310425;
-var summary = 'Array.indexOf/lastIndexOf edge cases';
+var BUGNUMBER = 352742;
+var summary = 'eval("return") in toString';
 var actual = '';
 var expect = '';
 
-printBugNumber(BUGNUMBER);
-printStatus (summary);
- 
-expect = -1;
-actual = Array(1).indexOf(1);
-reportCompare(expect, actual, summary);
+
+//-----------------------------------------------------------------------------
+test();
+//-----------------------------------------------------------------------------
+
+function test()
+{
+  enterFunc ('test');
+  printBugNumber(BUGNUMBER);
+  printStatus (summary);
+
+  expect = 3;
+  var j = ({toString: function() { eval("return"); }});
+  actual = 2;
+  try { "" + j; } catch(e){}
+  actual = 3;
+
+  reportCompare(expect, actual, summary);
+
+  exitFunc ('test');
+}
