@@ -1,11 +1,11 @@
-/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* -*- indent-tabs-mode: nil; js-indent-level: 2 -*- */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 //-----------------------------------------------------------------------------
 var BUGNUMBER = 346645;
-var summary = 'Do not crash with non-empty array in destructuring assign LHS';
+var summary = 'Do not crash with empty object in destructuring assign LHS';
 var actual = 'No Crash';
 var expect = 'No Crash';
 
@@ -19,10 +19,10 @@ function test()
   enterFunc ('test');
   printBugNumber(BUGNUMBER);
   printStatus (summary);
-
+ 
   try
   {
-    eval('({ a:[z] }) = 3;');
+    eval('({ a:{} }) = 3;');
   }
   catch(ex)
   {
