@@ -6,8 +6,8 @@
 //-----------------------------------------------------------------------------
 var BUGNUMBER = 354945;
 var summary = 'Do not crash with new Iterator';
-var expect = 'TypeError: trap __iterator__ for obj returned a primitive value';
-var actual;
+var actual = 'No Crash';
+var expect = 'No Crash';
 
 
 //-----------------------------------------------------------------------------
@@ -19,13 +19,17 @@ function test()
   enterFunc ('test');
   printBugNumber(BUGNUMBER);
   printStatus (summary);
-
-  try {
-    var obj = {};
-    obj.__iterator__ = function(){ };
-    for(t in (new Iterator(obj))) { }
-  } catch (ex) {
-    actual = ex.toString();
+ 
+  expect = 'TypeError: trap __iterator__ for obj returned a primitive value';
+  var obj = {};
+  obj.__iterator__ = function(){ };
+  try
+  {
+    for(t in (obj)) { }
+  }
+  catch(ex)
+  {
+    actual = ex + '';
   }
 
   reportCompare(expect, actual, summary);
