@@ -3,7 +3,7 @@
 // Any copyright is dedicated to the Public Domain.
 // http://creativecommons.org/licenses/publicdomain/
 
-function testRegExp(b) {
+function testRegExp(b, c=b) {
     var a = deserialize(serialize(b));
     assertEq(a === b, false);
     assertEq(Object.getPrototypeOf(a), RegExp.prototype);
@@ -11,11 +11,11 @@ function testRegExp(b) {
     for (p in a)
         throw new Error("cloned RegExp should have no enumerable properties");
 
-    assertEq(a.source, b.source);
-    assertEq(a.global, b.global);
-    assertEq(a.ignoreCase, b.ignoreCase);
-    assertEq(a.multiline, b.multiline);
-    assertEq(a.sticky, b.sticky);
+    assertEq(a.source, c.source);
+    assertEq(a.global, c.global);
+    assertEq(a.ignoreCase, c.ignoreCase);
+    assertEq(a.multiline, c.multiline);
+    assertEq(a.sticky, c.sticky);
     assertEq("expando" in a, false);
 }
 
@@ -27,7 +27,11 @@ testRegExp(RegExp.prototype);
 var re = /\bx\b/gi;
 re.expando = true;
 testRegExp(re);
+// the flag accessors are defined on RegExp.prototype, so they're
+// not available after re.__proto__ has been changed. We solve that by passing
+// in an additional copy of the same RegExp to compare the
+// serialized-then-deserialized clone with."
 re.__proto__ = {};
-testRegExp(re);
+testRegExp(re, /\bx\b/gi);
 
 reportCompare(0, 0, 'ok');
