@@ -4,13 +4,17 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch07/7.3/7.3-5.js
- * @description 7.3 - ES5 recognizes the character <LS> (\u2028) as terminating string literal
+ * @path ch07/7.6/7.6-33.js
+ * @description 7.6 - SyntaxError expected: reserved words used as Identifier Names in UTF8: super (super)
  */
 
 
 function testcase() {
-        var prop = "66\u2028123";
-        return prop === "66\u2028123" && prop[2] === "\u2028" && prop.length === 6;
+            try {
+                eval("var \u0073uper = 123;");  
+                return false;
+            } catch (e) {
+                return e instanceof SyntaxError;  
+            }
     }
 runTestCase(testcase);
