@@ -4,15 +4,22 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch07/7.6/7.6.1/7.6.1.2/7.6.1.2-16-s.js
- * @description Strict Mode - SyntaxError isn't thrown when '_implements' occurs in strict mode code
+ * @path ch07/7.6/7.6.1/7.6.1.2/7.6.1.2-2-s.js
+ * @description Strict Mode - SyntaxError is thrown when FutureReservedWord 'let' occurs in strict mode code
  * @onlyStrict
  */
 
 
+
+
 function testcase() {
         "use strict";
-        var _implements = 1;
-        return _implements === 1;
-    }
-runTestCase(testcase);
+
+        try {
+            eval("var let = 1;");
+            return false;
+        } catch (e) {
+            return e instanceof SyntaxError;
+        }
+}
+runTestCase(testcase);
\ No newline at end of file
