@@ -2,13 +2,13 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /**
- * 0xG is incorrect
+ * DecimalLiteral :: ExponentPart is incorrect
  *
- * @path ch07/7.8/7.8.3/S7.8.3_A6.2_T2.js
- * @description Checking if execution of "0xg" fails
+ * @path ch07/7.8/7.8.3/S7.8.3_A4.1_T2.js
+ * @description ExponentPart :: E DecimalDigits
  * @negative
  */
 
 //CHECK#1
-0xg
+E1
 
