@@ -4,16 +4,15 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch08/8.12/8.12.4/8.14.4-8-b_1.js
- * @description Non-writable property on a prototype written to.
+ * @path ch08/8.12/8.12.1/8.12.1-1_32.js
+ * @description Properties - [[HasOwnProperty]] (configurable, non-enumerable own setter property)
  */
 
-function testcase() {   
-    function foo() {};
-    Object.defineProperty(foo.prototype, "bar", {value: "unwritable"}); 
-    
-    var o = new foo(); 
-    o.bar = "overridden"; 
-    return o.hasOwnProperty("bar")===false && o.bar==="unwritable";
+function testcase() {
+
+    var o = {};
+    Object.defineProperty(o, "foo", {set: function() {;}, configurable:true});
+    return o.hasOwnProperty("foo");
+
 }
 runTestCase(testcase);
