@@ -4,13 +4,16 @@
 /// "Use Terms").   Any redistribution of this code must retain the above
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch10/10.4/10.4.3/10.4.3-1-62gs.js
- * @description Strict - checking 'this' from a global scope (strict function declaration called by non-strict function declaration)
+ * @path ch10/10.4/10.4.3/10.4.3-1-44gs.js
+ * @description Strict - checking 'this' from a global scope (Anonymous FunctionExpression defined within an Anonymous FunctionExpression with a strict directive prologue)
  * @onlyStrict
  */
 
-function f() { "use strict"; return this;};
-function foo() { return f();}
-if (foo()!==undefined){
+if (! ((function () {
+    "use strict";
+    return ((function () {
+        return typeof this;
+    })()==="undefined") && ((typeof this)==="undefined");
+})())) {
     throw "'this' had incorrect value!";
 }
\ No newline at end of file
