@@ -4,14 +4,13 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch10/10.4/10.4.3/10.4.3-1-54-s.js
- * @description Strict Mode - checking 'this' (Literal getter defined within strict mode)
- * @onlyStrict
+ * @path ch10/10.4/10.4.3/10.4.3-1-96-s.js
+ * @description Strict Mode - checking 'this' (non-strict function declaration called by strict Function.prototype.bind(null)())
+ * @noStrict
  */
     
 function testcase() {
-"use strict";
-var o = { get foo() { return this; } }
-return o.foo===o;
+function f() { return this===fnGlobalObject();};
+return (function () {"use strict"; return f.bind(null)(); })();
 }
 runTestCase(testcase);
\ No newline at end of file
