@@ -4,20 +4,27 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch11/11.4/11.4.1/11.4.1-5-a-18-s.js
- * @description Strict Mode - SyntaxError is thrown when deleting a built-in (Object)
+ * @path ch11/11.4/11.4.1/11.4.1-4-a-2-s.js
+ * @description Strict Mode - TypeError is thrown when deleting non-configurable accessor property
  * @onlyStrict
  */
 
 
 function testcase() {
         "use strict";
+        var obj = {};
+        Object.defineProperty(obj, "prop", {
+            get: function () {
+                return "abc"; 
+            },
+            configurable: false
+        });
 
         try {
-            eval("delete Object;");
+            delete obj.prop;
             return false;
         } catch (e) {
-            return e instanceof SyntaxError;
+            return e instanceof TypeError && obj.prop === "abc";
         }
     }
 runTestCase(testcase);
