@@ -4,20 +4,20 @@
 /**
  * First expression is evaluated first, and then second expression
  *
- * @path ch11/11.11/11.11.1/S11.11.1_A2.4_T1.js
+ * @path ch11/11.6/11.6.2/S11.6.2_A2.4_T1.js
  * @description Checking with "="
  */
 
 //CHECK#1
-var x = false; 
-if (((x = true) && x) !== true) {
-  $ERROR('#1: var x = false; ((x = true) && x) === true');
+var x = 0; 
+if ((x = 1) - x !== 0) {
+  $ERROR('#1: var x = 0; (x = 1) - x === 0. Actual: ' + ((x = 1) - x));
 }
 
 //CHECK#2
-var x = false; 
-if ((x && (x = true)) !== false) {
-  $ERROR('#2: var x = false; (x && (x = true)) === false');
+var x = 0; 
+if (x - (x = 1) !== -1) {
+  $ERROR('#2: var x = 0; x - (x = 1) === -1. Actual: ' + (x - (x = 1)));
 }
 
 
