@@ -4,20 +4,24 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch12/12.14/12.14.1/12.14.1-6-s.js
- * @description Strict Mode - SyntaxError isn't thrown if a TryStatement with a Catch occurs within strict code and the Identifier of the Catch production is ARGUMENTS
+ * @path ch12/12.2/12.2.1/12.2.1-22-s.js
+ * @description arguments as global var identifier throws SyntaxError in strict mode
  * @onlyStrict
  */
 
 
-function testcase() {
-        "use strict";
 
-        try {
-            throw new Error("...");
-            return false;
-        } catch (ARGUMENTS) {
-            return ARGUMENTS instanceof Error;
-        }
-    }
-runTestCase(testcase);
+
+function testcase() {
+
+    var indirectEval = eval;
+	
+    try {
+	    indirectEval("'use strict'; var arguments;");
+        return false;
+	}
+    catch (e) {
+        return (e instanceof SyntaxError);
+	}
+}
+runTestCase(testcase);
\ No newline at end of file
