@@ -1,14 +1,16 @@
 /// Copyright (c) 2012 Ecma International.  All rights reserved. 
 /// Ecma International makes this code available under the terms and conditions set
 /// forth on http://hg.ecmascript.org/tests/test262/raw-file/tip/LICENSE (the 
-/// "Use Terms").   Any redistribution of this code must retain the above
+/// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
+
 /**
- * @path ch13/13.1/13.1-4gs.js
- * @description Strict Mode - SyntaxError is thrown if the identifier 'arguments' appears within a FormalParameterList of a strict mode FunctionExpression
+ * @path ch13/13.0/13.0_4-5gs.js
+ * @description Strict Mode - SourceElements is evaluated as strict mode code when a FunctionDeclaration is contained in strict mode code
  * @onlyStrict
  * @negative ^((?!NotEarlyError).)*$
  */
+
 "use strict";
 throw NotEarlyError;
-var _13_1_4_fun = function (arguments) { };
\ No newline at end of file
+function _13_0_4_5_fun() { eval = 42; };
