@@ -4,21 +4,24 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch13/13.2/13.2-4-s.js
- * @description StrictMode - A TypeError is thrown when a code in strict mode tries to write to 'arguments' of function instances.
+ * Refer 13.1; 
+ * It is a SyntaxError if any Identifier value occurs more than once within a FormalParameterList of a strict mode
+ * FunctionDeclaration or FunctionExpression.
+ *
+ * @path ch13/13.1/13.1-10-s.js
+ * @description Strict Mode - SyntaxError is thrown if a function is created in 'strict mode' using a FunctionExpression and the function has three identical parameters
  * @onlyStrict
  */
 
 
 function testcase() {
         "use strict";
+
         try {
-            var foo = function () {
-            }
-            foo.arguments = 20;
+            eval("var _13_1_10_fun = function (param, param, param) { };")
             return false;
-        } catch (ex) {
-            return ex instanceof TypeError;
+        } catch (e) {
+            return e instanceof SyntaxError;
         }
     }
 runTestCase(testcase);
