@@ -4,8 +4,8 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch14/14.1/14.1-3-s.js
- * @description 'use strict' directive - not recognized if it contains extra whitespace
+ * @path ch14/14.1/14.1-10-s.js
+ * @description other directives - may follow 'use strict' directive
  * @noStrict
  */
 
@@ -14,8 +14,9 @@ function testcase() {
 
   function foo()
   {
-    '  use    strict   ';
-     return (this !== undefined);
+     "use strict";
+     "bogus directive";
+     return (this === undefined);
   }
 
   return foo.call(undefined);
