@@ -55,10 +55,11 @@ public:
 
 	//The following methods return true if the shape is
 	//partially or completely in front of the frustum planes
-	bool IsPointVisible (const CVector3D &point) const;
-	bool DoesSegmentIntersect(const CVector3D& start, const CVector3D &end);
-	bool IsSphereVisible (const CVector3D &center, float radius) const;
-	bool IsBoxVisible (const CVector3D &position,const CBoundingBoxAligned &bounds) const;
+	bool IsPointVisible(const CVector3D& point) const;
+	bool DoesSegmentIntersect(const CVector3D& start, const CVector3D& end) const;
+	bool IsSphereVisible(const CVector3D& center, float radius) const;
+	bool IsBoxVisible(const CVector3D& position, const CBoundingBoxAligned& bounds) const;
+	bool IsBoxVisible(const CBoundingBoxAligned& bounds) const;
 
 	CPlane& operator[](size_t idx) { return m_aPlanes[idx]; }
 	const CPlane& operator[](size_t idx) const { return m_aPlanes[idx]; }
