@@ -1053,7 +1053,7 @@ void CGameView::SetCameraProjection()
 InReaction game_view_handler(const SDL_Event_* ev)
 {
 	// put any events that must be processed even if inactive here
-	if(!g_app_has_focus || !g_Game || !g_Game->IsGameStarted())
+	if (!g_app_has_focus || !g_Game || !g_Game->IsGameStarted() || g_Game->GetView()->GetCinema()->IsEnabled())
 		return IN_PASS;
 
 	CGameView *pView=g_Game->GetView();
@@ -1076,16 +1076,19 @@ InReaction CGameView::HandleEvent(const SDL_Event_* ev)
 			else if (g_Renderer.GetModelRenderMode() == SOLID)
 			{
 				g_Renderer.SetTerrainRenderMode(EDGED_FACES);
+				g_Renderer.SetWaterRenderMode(EDGED_FACES);
 				g_Renderer.SetModelRenderMode(EDGED_FACES);
 			}
 			else if (g_Renderer.GetModelRenderMode() == EDGED_FACES)
 			{
 				g_Renderer.SetTerrainRenderMode(WIREFRAME);
+				g_Renderer.SetWaterRenderMode(WIREFRAME);
 				g_Renderer.SetModelRenderMode(WIREFRAME);
 			}
 			else
 			{
 				g_Renderer.SetTerrainRenderMode(SOLID);
+				g_Renderer.SetWaterRenderMode(SOLID);
 				g_Renderer.SetModelRenderMode(SOLID);
 			}
 			return IN_HANDLED;
