@@ -57,11 +57,6 @@ CMapReader::CMapReader()
 	: xml_reader(0), m_PatchesPerSide(0), m_MapGen(0)
 {
 	cur_terrain_tex = 0;	// important - resets generator state
-
-	// Maps that don't override the default probably want the old lighting model
-	//m_LightEnv.SetLightingModel("old");
-	//pPostproc->SetPostEffect(L"default");
-
 }
 
 // LoadMap: try to load the map from given file; reinitialise the scene to new data if successful
@@ -70,7 +65,6 @@ void CMapReader::LoadMap(const VfsPath& pathname, JSRuntime* rt,  JS::HandleValu
 						 CLightEnv *pLightEnv_, CGameView *pGameView_, CCinemaManager* pCinema_, CTriggerManager* pTrigMan_, CPostprocManager* pPostproc_,
 						 CSimulation2 *pSimulation2_, const CSimContext* pSimContext_, int playerID_, bool skipEntities)
 {
-	// latch parameters (held until DelayedLoadFinished)
 	pTerrain = pTerrain_;
 	pLightEnv = pLightEnv_;
 	pGameView = pGameView_;
@@ -145,8 +139,6 @@ void CMapReader::LoadMap(const VfsPath& pathname, JSRuntime* rt,  JS::HandleValu
 
 	// load map settings script (must be done after reading map)
 	RegMemFun(this, &CMapReader::LoadMapSettings, L"CMapReader::LoadMapSettings", 5);
-
-	RegMemFun(this, &CMapReader::DelayLoadFinished, L"CMapReader::DelayLoadFinished", 5);
 }
 
 // LoadRandomMap: try to load the map data; reinitialise the scene to new data if successful
@@ -155,7 +147,6 @@ void CMapReader::LoadRandomMap(const CStrW& scriptFile, JSRuntime* rt, JS::Handl
 						 CLightEnv *pLightEnv_, CGameView *pGameView_, CCinemaManager* pCinema_, CTriggerManager* pTrigMan_, CPostprocManager* pPostproc_,
 						 CSimulation2 *pSimulation2_, int playerID_)
 {
-	// latch parameters (held until DelayedLoadFinished)
 	m_ScriptFile = scriptFile;
 	pSimulation2 = pSimulation2_;
 	pSimContext = pSimulation2 ? &pSimulation2->GetSimContext() : NULL;
@@ -185,7 +176,7 @@ void CMapReader::LoadRandomMap(const CStrW& scriptFile, JSRuntime* rt, JS::Handl
 	RegMemFun(this, &CMapReader::LoadPlayerSettings, L"CMapReader::LoadPlayerSettings", 50);
 
 	// load map generator with random map script
-	RegMemFun(this, &CMapReader::GenerateMap, L"CMapReader::GenerateMap", 5000);
+	RegMemFun(this, &CMapReader::GenerateMap, L"CMapReader::GenerateMap", 20000);
 
 	// parse RMS results into terrain structure
 	RegMemFun(this, &CMapReader::ParseTerrain, L"CMapReader::ParseTerrain", 500);
@@ -207,21 +198,12 @@ void CMapReader::LoadRandomMap(const CStrW& scriptFile, JSRuntime* rt, JS::Handl
 
 	// load map settings script (must be done after reading map)
 	RegMemFun(this, &CMapReader::LoadMapSettings, L"CMapReader::LoadMapSettings", 5);
-
-	RegMemFun(this, &CMapReader::DelayLoadFinished, L"CMapReader::DelayLoadFinished", 5);
 }
 
 // UnpackMap: unpack the given data from the raw data stream into local variables
 int CMapReader::UnpackMap()
 {
-	// now unpack everything into local data
-	int ret = UnpackTerrain();
-	if (ret != 0)	// failed or timed out
-	{
-		return ret;
-	}
-
-	return 0;
+	return UnpackTerrain();
 }
 
 // UnpackTerrain: unpack the terrain from the end of the input data stream
@@ -385,7 +367,7 @@ PSRETURN CMapSummaryReader::LoadMap(const VfsPath& pathname)
 	return PSRETURN_OK;
 }
 
-void CMapSummaryReader::GetMapSettings(ScriptInterface& scriptInterface, JS::MutableHandleValue ret)
+void CMapSummaryReader::GetMapSettings(const ScriptInterface& scriptInterface, JS::MutableHandleValue ret)
 {
 	JSContext* cx = scriptInterface.GetContext();
 	JSAutoRequest rq(cx);
@@ -1213,14 +1195,6 @@ int CMapReader::ReadXMLEntities()
 	return ret;
 }
 
-int CMapReader::DelayLoadFinished()
-{
-	// we were dynamically allocated by CWorld::Initialize
-	delete this;
-
-	return 0;
-}
-
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1266,7 +1240,7 @@ int CMapReader::GenerateMap()
 	}
 	else if (progress == 0)
 	{
-		// Finished, get results as StructuredClone object, which must be read to obtain the JS val
+		// Finished, get results as StructuredClone object, which must be read to obtain the JS::Value
 		shared_ptr<ScriptInterface::StructuredClone> results = m_MapGen->GetResults();
 
 		// Parse data into simulation context
@@ -1409,7 +1383,7 @@ int CMapReader::ParseEntities()
 			CmpPtr<ICmpPosition> cmpPosition(sim, ent);
 			if (cmpPosition)
 			{
-				cmpPosition->JumpTo(currEnt.position.X, currEnt.position.Z);
+				cmpPosition->JumpTo(currEnt.position.X * (int)TERRAIN_TILE_SIZE, currEnt.position.Z * (int)TERRAIN_TILE_SIZE);
 				cmpPosition->SetYRotation(currEnt.rotation.Y);
 				// TODO: other parts of the position
 			}
