@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Wildfire Games.
+/* Copyright (C) 2015 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -15,42 +15,14 @@
  * along with 0 A.D.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/*
-GUI Object - Button
-
---Overview--
-
-	GUI Object representing a simple button
-
---More info--
-
-	Check GUI.h
-
-*/
-
 #ifndef INCLUDED_CBUTTON
 #define INCLUDED_CBUTTON
 
-//--------------------------------------------------------
-//  Includes / Compiler directives
-//--------------------------------------------------------
 #include "GUI.h"
 
-//--------------------------------------------------------
-//  Macros
-//--------------------------------------------------------
-
-//--------------------------------------------------------
-//  Types
-//--------------------------------------------------------
-
-//--------------------------------------------------------
-//  Declarations
-//--------------------------------------------------------
-
 /**
  * Button
- * 
+ *
  * @see IGUIObject
  * @see IGUIButtonBehavior
  */
@@ -70,7 +42,7 @@ public:
 	/**
 	 * @see IGUIObject#HandleMessage()
 	 */
-	virtual void HandleMessage(SGUIMessage &Message);
+	virtual void HandleMessage(SGUIMessage& Message);
 
 	/**
 	 * Draws the Button
@@ -90,4 +62,4 @@ protected:
 	CPos m_TextPos;
 };
 
-#endif
+#endif // INCLUDED_CBUTTON
