@@ -1,4 +1,4 @@
-/* Copyright (C) 2017 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -678,15 +678,26 @@ SGUIText CGUI::GenerateText(const CGUIString& string, const CStrW& FontW, const
 				x += Feedback2.m_Size.cx;
 
 				if (WordWrapping && x > width_range[To] && j!=temp_from && !Feedback2.m_NewLine)
+				{
+					// The calculated width of each word includes the space between the current
+					// word and the next. When we're wrapping, we need subtract the width of the
+					// space after the last word on the line before the wrap.
+					CFontMetrics currentFont(Font);
+					line_width -= currentFont.GetCharacterWidth(*L" ");
 					break;
+				}
 
 				// Let line_height be the maximum m_Height we encounter.
 				line_height = std::max(line_height, Feedback2.m_Size.cy);
 
-				line_width += Feedback2.m_Size.cx;
-
+				// If the current word is an explicit new line ("\n"),
+				// break now before adding the width of this character.
+				// ("\n" doesn't have a glyph, thus is given the same width as
+				// the "missing glyph" character by CFont::GetCharacterWidth().)
 				if (WordWrapping && Feedback2.m_NewLine)
 					break;
+
+				line_width += Feedback2.m_Size.cx;
 			}
 
 			float dx = 0.f;
@@ -746,8 +757,6 @@ SGUIText CGUI::GenerateText(const CGUIString& string, const CStrW& FontW, const
 				// Append X value.
 				x += Feedback2.m_Size.cx;
 
-				Text.m_Size.cx = std::max(Text.m_Size.cx, x+BufferZone);
-
 				// The first word overrides the width limit, what we
 				//  do, in those cases, are just drawing that word even
 				//  though it'll extend the object.
@@ -783,10 +792,11 @@ SGUIText CGUI::GenerateText(const CGUIString& string, const CStrW& FontW, const
 			}
 
 			// Reset X
-			x = 0.f;
+			x = BufferZone;
 
-			// Update height of all
-			Text.m_Size.cy = std::max(Text.m_Size.cy, y+BufferZone);
+			// Update dimensions
+			Text.m_Size.cx = std::max(Text.m_Size.cx, line_width + BufferZone * 2);
+			Text.m_Size.cy = std::max(Text.m_Size.cy, y + BufferZone);
 
 			FirstLine = false;
 
