@@ -1,4 +1,4 @@
-/* Copyright (C) 2015 Wildfire Games.
+/* Copyright (C) 2016 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -20,7 +20,10 @@
 #include "GUI.h"
 #include "CList.h"
 
-struct ObjectDef
+/**
+ * Represents a column.
+ */
+struct COListColumn
 {
   CColor m_TextColor;
   CStr m_Id;
@@ -34,7 +37,7 @@ struct ObjectDef
  * Individual cells are clipped if the contained text is too long.
  *
  * The list can be sorted dynamically by JS code when a
- * heading is ckicked.
+ * heading is clicked.
  * A scroll-bar will appear when needed.
  */
 class COList : public CList
@@ -57,14 +60,14 @@ protected:
 
 	virtual CRect GetListRect() const;
 
-	std::vector<ObjectDef> m_ObjectsDefs;
-	size_t m_SelectedDef;
-	int m_SelectedColumnOrder;
+	/**
+	 * Available columns.
+	 */
+	std::vector<COListColumn> m_Columns;
 
 private:
-	float m_HeadingHeight;
-	// Width of space avalible for columns
-	float m_TotalAvalibleColumnWidth;
+	// Width of space available for columns
+	float m_TotalAvailableColumnWidth;
 };
 
 #endif // INCLUDED_COLIST
