@@ -156,6 +156,17 @@ bool JSI_IGUIObject::getProperty(JSContext* cx, JS::HandleObject obj, JS::Handle
 			break;
 		}
 
+		case GUIST_uint:
+		{
+			u32 value;
+			GUI<u32>::GetSetting(e, propName, value);
+			if (value >= std::numeric_limits<u32>::max())
+				LOGERROR("Integer overflow on converting to GUIST_uint");
+			else
+				vp.set(JS::Int32Value(value));
+			break;
+		}
+
 		case GUIST_float:
 		{
 			float value;
@@ -452,6 +463,19 @@ bool JSI_IGUIObject::setProperty(JSContext* cx, JS::HandleObject obj, JS::Handle
 		break;
 	}
 
+	case GUIST_uint:
+	{
+		u32 value;
+		if (ScriptInterface::FromJSVal(cx, vp, value))
+			GUI<u32>::SetSetting(e, propName, value);
+		else
+		{
+			JS_ReportError(cx, "Cannot convert value to u32");
+			return false;
+		}
+		break;
+	}
+
 	case GUIST_float:
 	{
 		double value;
@@ -587,7 +611,7 @@ bool JSI_IGUIObject::setProperty(JSContext* cx, JS::HandleObject obj, JS::Handle
 }
 
 
-bool JSI_IGUIObject::construct(JSContext* cx, uint argc, jsval* vp)
+bool JSI_IGUIObject::construct(JSContext* cx, uint argc, JS::Value* vp)
 {
 	JSAutoRequest rq(cx);
 	JS::CallArgs args = JS::CallArgsFromVp(argc, vp);
@@ -614,7 +638,7 @@ void JSI_IGUIObject::init(ScriptInterface& scriptInterface)
 	scriptInterface.DefineCustomObjectType(&JSI_class, construct, 1, JSI_props, JSI_methods, NULL, NULL);
 }
 
-bool JSI_IGUIObject::toString(JSContext* cx, uint UNUSED(argc), jsval* vp)
+bool JSI_IGUIObject::toString(JSContext* cx, uint UNUSED(argc), JS::Value* vp)
 {
 	JSAutoRequest rq(cx);
 	JS::CallReceiver rec = JS::CallReceiverFromVp(vp);
@@ -632,7 +656,7 @@ bool JSI_IGUIObject::toString(JSContext* cx, uint UNUSED(argc), jsval* vp)
 	return true;
 }
 
-bool JSI_IGUIObject::focus(JSContext* cx, uint UNUSED(argc), jsval* vp)
+bool JSI_IGUIObject::focus(JSContext* cx, uint UNUSED(argc), JS::Value* vp)
 {
 	JSAutoRequest rq(cx);
 	JS::CallReceiver rec = JS::CallReceiverFromVp(vp);
@@ -649,7 +673,7 @@ bool JSI_IGUIObject::focus(JSContext* cx, uint UNUSED(argc), jsval* vp)
 	return true;
 }
 
-bool JSI_IGUIObject::blur(JSContext* cx, uint UNUSED(argc), jsval* vp)
+bool JSI_IGUIObject::blur(JSContext* cx, uint UNUSED(argc), JS::Value* vp)
 {
 	JSAutoRequest rq(cx);
 	JS::CallReceiver rec = JS::CallReceiverFromVp(vp);
@@ -666,7 +690,7 @@ bool JSI_IGUIObject::blur(JSContext* cx, uint UNUSED(argc), jsval* vp)
 	return true;
 }
 
-bool JSI_IGUIObject::getComputedSize(JSContext* cx, uint UNUSED(argc), jsval* vp)
+bool JSI_IGUIObject::getComputedSize(JSContext* cx, uint UNUSED(argc), JS::Value* vp)
 {
 	JSAutoRequest rq(cx);
 	JS::CallReceiver rec = JS::CallReceiverFromVp(vp);
