@@ -1,4 +1,4 @@
-/* Copyright (C) 2016 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of this software and associated documentation files (the
@@ -191,3 +191,25 @@ Status DeleteDirectory(const OsPath& path)
 
 	return INFO::OK;
 }
+
+
+Status CopyFile(const OsPath& path, const OsPath& newPath, bool override_if_exists/* = false*/)
+{
+	if(path.empty())
+		return INFO::OK;
+
+	try
+	{
+		if(override_if_exists)
+			fs::copy_file(path.string8(), newPath.string8(), boost::filesystem::copy_option::overwrite_if_exists);
+		else
+			fs::copy_file(path.string8(), newPath.string8());
+	}
+	catch(fs::filesystem_error& err)
+	{
+		debug_printf("CopyFile: failed to copy %s to %s.\n%s\n", path.string8().c_str(), path.string8().c_str(), err.what());
+		return ERR::EXCEPTION;
+	}
+
+	return INFO::OK;
+}
