@@ -1,4 +1,4 @@
-/* Copyright (c) 2013 Wildfire Games
+/* Copyright (C) 2017 Wildfire Games.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of this software and associated documentation files (the
@@ -7,10 +7,10 @@
  * distribute, sublicense, and/or sell copies of the Software, and to
  * permit persons to whom the Software is furnished to do so, subject to
  * the following conditions:
- * 
+ *
  * The above copyright notice and this permission notice shall be included
  * in all copies or substantial portions of the Software.
- * 
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
  * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
  * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
@@ -373,10 +373,9 @@ static void importExtensionFunctions()
 
 //----------------------------------------------------------------------------
 
-static void dump_gl_error(GLenum err)
+const char* ogl_GetErrorName(GLenum err)
 {
-	debug_printf("OGL| ");
-#define E(e) case e: debug_printf("%s\n", #e); break;
+#define E(e) case e: return #e;
 	switch (err)
 	{
 	E(GL_INVALID_ENUM)
@@ -388,11 +387,16 @@ static void dump_gl_error(GLenum err)
 #endif
 	E(GL_OUT_OF_MEMORY)
 	E(GL_INVALID_FRAMEBUFFER_OPERATION)
-	default: debug_printf("Unknown GL error: %04x\n", err); break;
+	default: return "Unknown GL error";
 	}
 #undef E
 }
 
+static void dump_gl_error(GLenum err)
+{
+	debug_printf("OGL| %s (%04x)\n", ogl_GetErrorName(err), err);
+}
+
 void ogl_WarnIfErrorLoc(const char *file, int line)
 {
 	// glGetError may return multiple errors, so we poll it in a loop.
@@ -414,7 +418,7 @@ void ogl_WarnIfErrorLoc(const char *file, int line)
 	}
 
 	if(error_enountered)
-		debug_printf("%s:%d: OpenGL error(s) occurred: %04x\n", file, line, (unsigned int)first_error);
+		debug_printf("%s:%d: OpenGL error(s) occurred: %s (%04x)\n", file, line, ogl_GetErrorName(first_error), (unsigned int)first_error);
 }
 
 
