@@ -1,4 +1,4 @@
-/* Copyright (c) 2013 Wildfire Games
+/* Copyright (C) 2017 Wildfire Games.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of this software and associated documentation files (the
@@ -7,10 +7,10 @@
  * distribute, sublicense, and/or sell copies of the Software, and to
  * permit persons to whom the Software is furnished to do so, subject to
  * the following conditions:
- * 
+ *
  * The above copyright notice and this permission notice shall be included
  * in all copies or substantial portions of the Software.
- * 
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
  * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
  * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
@@ -71,7 +71,7 @@ LIB_API bool path_is_subpath(const wchar_t* s1, const wchar_t* s2);
 LIB_API const wchar_t* path_name_only(const wchar_t* path);
 
 
-// NB: there is a need for 'generic' paths (e.g. for Trace entry / archive pathnames). 
+// NB: there is a need for 'generic' paths (e.g. for Trace entry / archive pathnames).
 // converting between specialized variants via c_str would be inefficient, and the
 // Os/VfsPath typedefs are hopefully sufficient to avoid errors.
 class Path
@@ -135,11 +135,20 @@ public:
 	 */
 	std::string string8() const
 	{
-		// TODO: On Unixes, this will only be correct for ASCII or ISO-8859-1
-		// encoded paths; we should probably assume UTF-8 encoding by default
-		// (but take care to handle non-valid-UTF-8 paths safely).
+		Status err;
+#if !OS_WIN
+		// On Unix, assume paths consisting of 8-bit charactes saved in this wide string.
+		std::string spath(path.begin(), path.end());
 
-		return utf8_from_wstring(path);
+		// Return it if it's valid UTF-8
+		wstring_from_utf8(spath, &err);
+		if(err == INFO::OK)
+			return spath;
+
+		// Otherwise assume ISO-8859-1 and let utf8_from_wstring treat each character as a Unicode code point.
+#endif
+		// On Windows, paths are UTF-16 strings. We don't support non-BMP characters so we can assume it's simply a wstring.
+		return utf8_from_wstring(path, &err);
 	}
 
 	bool operator<(const Path& rhs) const
