@@ -1,4 +1,4 @@
-/* Copyright (C) 2010 Wildfire Games.
+/* Copyright (C) 2017 Wildfire Games.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of this software and associated documentation files (the
@@ -59,11 +59,13 @@ typedef enum
 clockid_t;
 
 // POSIX realtime clock_*
+#if _MSC_VER < 1900
 struct timespec
 {
 	time_t tv_sec;
 	long   tv_nsec;
 };
+#endif
 
 extern int nanosleep(const struct timespec* rqtp, struct timespec* rmtp);
 extern int clock_gettime(clockid_t clock, struct timespec* ts);
