@@ -1,4 +1,4 @@
-/* Copyright (C) 2017 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of this software and associated documentation files (the
@@ -51,7 +51,7 @@ class S3tcBlock
 {
 public:
 	S3tcBlock(size_t dxt, const u8* RESTRICT block)
-		: dxt(dxt)
+		: m_Dxt(dxt)
 	{
 		// (careful, 'dxt != 1' doesn't work - there's also DXT1a)
 		const u8* a_block = block;
@@ -71,23 +71,23 @@ public:
 			out[i] = (u8)c[c_selector][i];
 
 		// if no alpha, done
-		if(dxt == 1)
+		if(m_Dxt == 1)
 			return;
 
 		size_t a;
-		if(dxt == 3)
+		if(m_Dxt == 3)
 		{
 			// table of 4-bit alpha entries
 			a = access_bit_tbl(a_bits, pixel_idx, 4);
 			a |= a << 4; // expand to 8 bits (replicate high into low!)
 		}
-		else if(dxt == 5)
+		else if(m_Dxt == 5)
 		{
 			// pixel index -> alpha selector (3 bit) -> alpha
 			const size_t a_selector = access_bit_tbl(a_bits, pixel_idx, 3);
 			a = dxt5_a_tbl[a_selector];
 		}
-		// (dxt == DXT1A)
+		// (m_Dxt == DXT1A)
 		else
 			a = c[c_selector][A];
 		out[A] = (u8)(a & 0xFF);
@@ -214,7 +214,7 @@ private:
 	// table of 2-bit color selectors
 	u32 c_selectors;
 
-	size_t dxt;
+	size_t m_Dxt;
 };
 
 
@@ -283,7 +283,7 @@ static Status s3tc_decompress(Tex* t)
 	const size_t out_bpp = (dxt != 1)? 32 : 24;
 	const size_t out_size = t->img_size() * out_bpp / t->m_Bpp;
 	shared_ptr<u8> decompressedData;
-	AllocateAligned(decompressedData, out_size, pageSize);
+	AllocateAligned(decompressedData, out_size, g_PageSize);
 
 	const size_t s3tc_block_size = (dxt == 3 || dxt == 5)? 16 : 8;
 	S3tcDecompressInfo di = { dxt, s3tc_block_size, out_bpp/8, decompressedData.get() };
