@@ -16,6 +16,7 @@
  */
 
 #include "precompiled.h"
+
 #include "XmppClient.h"
 #include "StanzaExtensions.h"
 
@@ -24,7 +25,6 @@
 #endif
 
 #include "i18n/L10n.h"
-
 #include "lib/external_libraries/enet.h"
 #include "lib/utf8.h"
 #include "network/NetServer.h"
@@ -34,6 +34,8 @@
 #include "ps/Pyrogenesis.h"
 #include "scriptinterface/ScriptInterface.h"
 
+#include <gloox/gloox.h>
+
 //debug
 #if 1
 #define DbgXMPP(x)
@@ -96,8 +98,11 @@ XmppClient::XmppClient(const std::string& sUsername, const std::string& sPasswor
 	else
 		m_client = new glooxwrapper::Client(m_server);
 
-	// Disable TLS as we haven't set a certificate on the server yet
-	m_client->setTls(gloox::TLSDisabled);
+	// Optionally join without a TLS certificate, so a local server can be tested  quickly.
+	// Security risks from malicious JS mods can be mitigated if this option and also the hostname and login are shielded from JS access.
+	bool tls = true;
+	CFG_GET_VAL("lobby.tls", tls);
+	m_client->setTls(tls ? gloox::TLSRequired : gloox::TLSDisabled);
 
 	// Disable use of the SASL PLAIN mechanism, to prevent leaking credentials
 	// if the server doesn't list any supported SASL mechanism or the response
@@ -248,11 +253,10 @@ void XmppClient::onDisconnect(gloox::ConnectionError error)
 }
 
 /**
- * Handle TLS connection
+ * Handle TLS connection.
  */
 bool XmppClient::onTLSConnect(const glooxwrapper::CertInfo& info)
 {
-	UNUSED2(info);
 	DbgXMPP("onTLSConnect");
 	DbgXMPP(
 		"status: " << info.status <<
@@ -262,7 +266,14 @@ bool XmppClient::onTLSConnect(const glooxwrapper::CertInfo& info)
 		"\nmac: " << info.mac <<
 		"\ncipher: " << info.cipher <<
 		"\ncompression: " << info.compression );
-	return true;
+
+	m_certStatus = static_cast<gloox::CertStatus>(info.status);
+
+	// Optionally accept invalid certificates, see require_tls option.
+	bool verify_certificate = true;
+	CFG_GET_VAL("lobby.verify_certificate", verify_certificate);
+
+	return info.status == gloox::CertOk || !verify_certificate;
 }
 
 /**
@@ -778,6 +789,8 @@ bool XmppClient::handleIq(const glooxwrapper::IQ& iq)
 
 			if (g_NetServer)
 				g_NetServer->OnLobbyAuth(iq.from().username(), lobbyAuth->m_Token.to_string());
+			else
+				LOGERROR("Received lobby authentication request, but not hosting currently!");
 		}
 	}
 	else if (iq.subtype() == gloox::IQ::Error)
@@ -1045,6 +1058,32 @@ void XmppClient::GetRoleString(const gloox::MUCRoomRole r, std::string& role) co
 	}
 }
 
+/**
+ * Translates a gloox certificate error codes, i.e. gloox certificate statuses except CertOk.
+ * Keep in sync with specifications.
+ */
+std::string XmppClient::TLSErrorToString(gloox::CertStatus status) const
+{
+	// TODO: Use translation
+	std::map<gloox::CertStatus, std::string> certificateErrorStrings = {
+		{ gloox::CertInvalid, ("The certificate is not trusted.") },
+		{ gloox::CertSignerUnknown, ("The certificate hasn't got a known issuer.") },
+		{ gloox::CertRevoked, ("The certificate has been revoked.") },
+		{ gloox::CertExpired, ("The certificate has expired.") },
+		{ gloox::CertNotActive, ("The certifiacte is not yet active.") },
+		{ gloox::CertWrongPeer, ("The certificate has not been issued for the peer we're connected to.") },
+		{ gloox::CertSignerNotCa, ("The signer is not a CA.") }
+	};
+
+	std::string result = "";
+
+	for (std::map<gloox::CertStatus, std::string>::iterator it = certificateErrorStrings.begin(); it != certificateErrorStrings.end(); ++it)
+		if (status & it->first)
+			result += "\n" + it->second;
+
+	return result;
+}
+
 /**
  * Convert a gloox stanza error type to string.
  * Keep in sync with Gloox documentation
@@ -1115,7 +1154,7 @@ std::string XmppClient::ConnectionErrorToString(gloox::ConnectionError err) cons
 	CASE(ConnDnsError, g_L10n.Translate("Resolving the server's hostname failed"));
 	CASE(ConnOutOfMemory, g_L10n.Translate("This system is out of memory"));
 	DEBUG_CASE(ConnNoSupportedAuth, "The authentication mechanisms the server offered are not supported or no authentication mechanisms were available");
-	CASE(ConnTlsFailed, g_L10n.Translate("The server's certificate could not be verified or the TLS handshake did not complete successfully"));
+	CASE(ConnTlsFailed, g_L10n.Translate("The server's certificate could not be verified or the TLS handshake did not complete successfully") + TLSErrorToString(m_certStatus));
 	CASE(ConnTlsNotAvailable, g_L10n.Translate("The server did not offer required TLS encryption"));
 	DEBUG_CASE(ConnCompressionFailed, "Negotiation/initializing compression failed");
 	CASE(ConnAuthenticationFailed, g_L10n.Translate("Authentication failed. Incorrect password or account does not exist"));
@@ -1187,5 +1226,11 @@ void XmppClient::handleSessionInitiation(const glooxwrapper::Jingle::Session::Ji
 		return;
 	}
 
+	if (!g_NetServer)
+	{
+		LOGERROR("Received STUN connection request, but not hosting currently!");
+		return;
+	}
+
 	g_NetServer->SendHolePunchingMessage(candidate.ip.to_string(), candidate.port);
 }
