@@ -1,4 +1,4 @@
-/* Copyright (C) 2017 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -216,18 +216,14 @@ public:
 		m_Wrapped->handleRegistrationResult(fromWrapped, regResult);
 	}
 
-	virtual void handleDataForm(const gloox::JID& from, const gloox::DataForm& UNUSED(form))
+	virtual void handleDataForm(const gloox::JID& UNUSED(from), const gloox::DataForm& UNUSED(form))
 	{
-		glooxwrapper::JID fromWrapped(from);
 		/* DataForm not supported */
-		m_Wrapped->handleDataForm(fromWrapped, *(glooxwrapper::DataForm*)NULL);
 	}
 
-	virtual void handleOOB(const gloox::JID& from, const gloox::OOB& UNUSED(oob))
+	virtual void handleOOB(const gloox::JID& UNUSED(from), const gloox::OOB& UNUSED(oob))
 	{
-		glooxwrapper::JID fromWrapped(from);
 		/* OOB not supported */
-		m_Wrapped->handleOOB(fromWrapped, *(glooxwrapper::OOB*)NULL);
 	}
 };
 
@@ -346,6 +342,11 @@ gloox::ConnectionError glooxwrapper::Client::recv(int timeout)
 	return m_Wrapped->recv(timeout);
 }
 
+const glooxwrapper::string glooxwrapper::Client::getID() const
+{
+	return m_Wrapped->getID();
+}
+
 void glooxwrapper::Client::send(const IQ& iq)
 {
 	m_Wrapped->send(iq.getWrapped());
@@ -463,7 +464,10 @@ const glooxwrapper::StanzaExtension* glooxwrapper::IQ::findExtension(int type) c
 
 gloox::StanzaError glooxwrapper::IQ::error_error() const
 {
-	return m_Wrapped->error()->error();
+	const gloox::Error* error = m_Wrapped->error();
+	if (!error)
+		return gloox::StanzaErrorInternalServerError;
+	return error->error();
 }
 
 glooxwrapper::Tag* glooxwrapper::IQ::tag() const
@@ -476,6 +480,15 @@ gloox::IQ::IqType glooxwrapper::IQ::subtype() const
 	return m_Wrapped->subtype();
 }
 
+const glooxwrapper::string glooxwrapper::IQ::id() const
+{
+	return m_Wrapped->id();
+}
+
+const gloox::JID& glooxwrapper::IQ::from() const
+{
+	return m_Wrapped->from();
+}
 
 glooxwrapper::JID::JID()
 {
