@@ -1,4 +1,4 @@
-/* Copyright (C) 2017 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -394,6 +394,7 @@ namespace glooxwrapper
 
 		bool connect(bool block = true);
 		gloox::ConnectionError recv(int timeout = -1);
+		const string getID() const;
 		void send(const IQ& iq);
 
 		void setTls(gloox::TLSPolicy tls);
@@ -448,7 +449,7 @@ namespace glooxwrapper
 		const gloox::IQ& getWrapped() const { return *m_Wrapped; }
 		IQ(const gloox::IQ& iq) : m_Wrapped(const_cast<gloox::IQ*>(&iq)), m_Owned(false) { }
 
-		IQ(gloox::IQ::IqType type, const JID& to, const string& id = "");
+		IQ(gloox::IQ::IqType type, const JID& to, const string& id);
 		~IQ();
 
 		void addExtension(const StanzaExtension* se);
@@ -461,6 +462,8 @@ namespace glooxwrapper
 		}
 
 		gloox::IQ::IqType subtype() const;
+		const string id() const;
+		const gloox::JID& from() const;
 
 		gloox::StanzaError error_error() const; // wrapper for ->error()->error()
 		Tag* tag() const;
