@@ -181,11 +181,11 @@ void CNetClient::SetAndOwnSession(CNetClientSession* session)
 
 void CNetClient::DestroyConnection()
 {
-	// Send network messages from the current frame before connection is destroyed.
+	// Attempt to send network messages from the current frame before connection is destroyed.
 	if (m_ClientTurnManager)
 	{
-		m_ClientTurnManager->OnDestroyConnection(); // End sending of commands for scheduled turn.
-		Flush(); // Make sure the messages are sent.
+		m_ClientTurnManager->OnDestroyConnection();
+		Flush();
 	}
 	SAFE_DELETE(m_Session);
 }
@@ -672,6 +672,8 @@ bool CNetClient::OnPlayerAssignment(void* context, CFsmEvent* event)
 	return true;
 }
 
+// This is called either when the host clicks the StartGame button or
+// if this client rejoins and finishes the download of the simstate.
 bool CNetClient::OnGameStart(void* context, CFsmEvent* event)
 {
 	ENSURE(event->GetType() == (uint)NMT_GAME_START);
@@ -680,6 +682,8 @@ bool CNetClient::OnGameStart(void* context, CFsmEvent* event)
 	JSContext* cx = client->GetScriptInterface().GetContext();
 	JSAutoRequest rq(cx);
 
+	client->m_Session->SetLongTimeout(true);
+
 	// Find the player assigned to our GUID
 	int player = -1;
 	if (client->m_PlayerAssignments.find(client->m_GUID) != client->m_PlayerAssignments.end())
@@ -775,9 +779,6 @@ bool CNetClient::OnClientTimeout(void *context, CFsmEvent* event)
 	JSContext* cx = client->GetScriptInterface().GetContext();
 	JSAutoRequest rq(cx);
 
-	if (client->GetCurrState() == NCS_LOADING)
-		return true;
-
 	CClientTimeoutMessage* message = (CClientTimeoutMessage*)event->GetParamRef();
 	JS::RootedValue msg(cx);
 
@@ -799,9 +800,6 @@ bool CNetClient::OnClientPerformance(void *context, CFsmEvent* event)
 	JSContext* cx = client->GetScriptInterface().GetContext();
 	JSAutoRequest rq(cx);
 
-	if (client->GetCurrState() == NCS_LOADING)
-		return true;
-
 	CClientPerformanceMessage* message = (CClientPerformanceMessage*)event->GetParamRef();
 
 	// Display warnings for other clients with bad ping
@@ -826,15 +824,26 @@ bool CNetClient::OnClientsLoading(void *context, CFsmEvent *event)
 
 	CClientsLoadingMessage* message = (CClientsLoadingMessage*)event->GetParamRef();
 
-	std::vector<CStr> guids;
-	guids.reserve(message->m_Clients.size());
-	for (const CClientsLoadingMessage::S_m_Clients& client : message->m_Clients)
-		guids.push_back(client.m_GUID);
-
 	CNetClient* client = (CNetClient*)context;
 	JSContext* cx = client->GetScriptInterface().GetContext();
 	JSAutoRequest rq(cx);
 
+	bool finished = true;
+	std::vector<CStr> guids;
+	guids.reserve(message->m_Clients.size());
+	for (const CClientsLoadingMessage::S_m_Clients& mClient : message->m_Clients)
+	{
+		if (client->m_GUID == mClient.m_GUID)
+			finished = false;
+
+		guids.push_back(mClient.m_GUID);
+	}
+
+	// Disable the timeout here after processing the enet message, so as to ensure that the connection isn't currently
+	// timing out (as it is when just leaving the loading screen in LoadFinished).
+	if (finished)
+		client->m_Session->SetLongTimeout(false);
+
 	JS::RootedValue msg(cx);
 	client->GetScriptInterface().Eval("({ 'type':'clients-loading' })", &msg);
 	client->GetScriptInterface().SetProperty(msg, "guids", guids);
@@ -881,6 +890,9 @@ bool CNetClient::OnLoadedGame(void* context, CFsmEvent* event)
 	if (client->m_Rejoin)
 		client->SendRejoinedMessage();
 
+	// The last client to leave the loading screen didn't receive the CClientsLoadingMessage, so disable here.
+	client->m_Session->SetLongTimeout(false);
+
 	return true;
 }
 
