@@ -1,4 +1,4 @@
-/* Copyright (C) 2017 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -95,7 +95,10 @@ void CNetClientTurnManager::NotifyFinishedUpdate(u32 turn)
 
 void CNetClientTurnManager::OnDestroyConnection()
 {
-	NotifyFinishedOwnCommands(m_CurrentTurn + COMMAND_DELAY);
+	// Attempt to flush messages before leaving.
+	// Notice the sending is not reliable and rarely makes it to the Server.
+	if (m_NetClient.GetCurrState() == NCS_INGAME)
+		NotifyFinishedOwnCommands(m_CurrentTurn + COMMAND_DELAY);
 }
 
 void CNetClientTurnManager::OnSimulationMessage(CSimulationMessage* msg)
@@ -123,6 +126,10 @@ void CNetClientTurnManager::OnSyncError(u32 turn, const CStr& expectedHash, cons
 	m_Simulation2.DumpDebugState(file);
 	file.close();
 
+	std::ofstream binfile (OsString(oosdumpPath.ChangeExtension(L".dat")).c_str(), std::ofstream::out | std::ofstream::trunc | std::ofstream::binary);
+	m_Simulation2.SerializeState(binfile);
+	binfile.close();
+
 	std::stringstream playerNamesString;
 	std::vector<CStr> playerNamesStrings;
 	playerNamesStrings.reserve(playerNames.size());
