@@ -26,11 +26,13 @@
 #include "NetStats.h"
 
 #include "lib/external_libraries/enet.h"
+#include "lib/types.h"
 #include "network/StunClient.h"
 #include "ps/CLogger.h"
 #include "ps/ConfigDB.h"
 #include "ps/GUID.h"
 #include "ps/Profile.h"
+#include "ps/ThreadUtil.h"
 #include "scriptinterface/ScriptInterface.h"
 #include "scriptinterface/ScriptRuntime.h"
 #include "simulation2/Simulation2.h"
@@ -43,6 +45,8 @@
 #include <miniupnpc/upnperrors.h>
 #endif
 
+#include <string>
+
 /**
  * Number of peers to allocate for the enet host.
  * Limited by ENET_PROTOCOL_MAXIMUM_PEER_ID (4096).
@@ -553,9 +557,6 @@ bool CNetServerWorker::RunStep()
 
 void CNetServerWorker::CheckClientConnections()
 {
-	if (m_State == SERVER_STATE_LOADING)
-		return;
-
 	// Send messages at most once per second
 	std::time_t now = std::time(nullptr);
 	if (now <= m_LastConnectionCheck)
@@ -590,12 +591,14 @@ void CNetServerWorker::CheckClientConnections()
 		}
 
 		// Send to all clients except the affected one
-		// (since that will show the locally triggered warning instead)
+		// (since that will show the locally triggered warning instead).
+		// Also send it to clients that finished the loading screen while
+		// the game is still waiting for other clients to finish the loading screen.
 		if (message)
 			for (size_t j = 0; j < m_Sessions.size(); ++j)
 			{
 				if (i != j && (
-				    m_Sessions[j]->GetCurrState() == NSS_PREGAME ||
+				    (m_Sessions[j]->GetCurrState() == NSS_PREGAME && m_State == SERVER_STATE_PREGAME) ||
 				    m_Sessions[j]->GetCurrState() == NSS_INGAME))
 				{
 					m_Sessions[j]->SendMessage(message);
@@ -801,7 +804,7 @@ void CNetServerWorker::KickPlayer(const CStrW& playerName, const bool ban)
 	{
 		// Remember name
 		if (std::find(m_BannedPlayers.begin(), m_BannedPlayers.end(), playerName) == m_BannedPlayers.end())
-			m_BannedPlayers.push_back(playerName);
+			m_BannedPlayers.push_back(m_LobbyAuth ? CStrW(playerName.substr(0, playerName.find(L" ("))) : playerName);
 
 		// Remember IP address
 		u32 ipAddress = (*it)->GetIPAddress();
@@ -985,7 +988,7 @@ bool CNetServerWorker::OnAuthenticate(void* context, CFsmEvent* event)
 	}
 
 	// Disconnect banned usernames
-	if (std::find(server.m_BannedPlayers.begin(), server.m_BannedPlayers.end(), username) != server.m_BannedPlayers.end())
+	if (std::find(server.m_BannedPlayers.begin(), server.m_BannedPlayers.end(), server.m_LobbyAuth ? usernameWithoutRating : username) != server.m_BannedPlayers.end())
 	{
 		session->Disconnect(NDR_BANNED);
 		return true;
@@ -1096,6 +1099,9 @@ bool CNetServerWorker::OnAuthenticate(void* context, CFsmEvent* event)
 		// Assume session 0 is most likely the local player, so they're
 		// the most efficient client to request a copy from
 		CNetServerSession* sourceSession = server.m_Sessions.at(0);
+
+		session->SetLongTimeout(true);
+
 		sourceSession->GetFileTransferer().StartTask(
 			shared_ptr<CNetFileReceiveTask>(new CNetFileReceiveTask_ServerRejoin(server, newHostID))
 		);
@@ -1218,6 +1224,11 @@ bool CNetServerWorker::OnGameSetup(void* context, CFsmEvent* event)
 	CNetServerSession* session = (CNetServerSession*)context;
 	CNetServerWorker& server = session->GetServer();
 
+	// Changing the settings after gamestart is not implemented and would cause an Out-of-sync error.
+	// This happened when doubleclicking on the startgame button.
+	if (server.m_State != SERVER_STATE_PREGAME)
+		return true;
+
 	if (session->GetGUID() == server.m_HostGUID)
 	{
 		CGameSetupMessage* message = (CGameSetupMessage*)event->GetParamRef();
@@ -1259,6 +1270,8 @@ bool CNetServerWorker::OnLoadedGame(void* context, CFsmEvent* event)
 	CNetServerSession* loadedSession = (CNetServerSession*)context;
 	CNetServerWorker& server = loadedSession->GetServer();
 
+	loadedSession->SetLongTimeout(false);
+
 	// We're in the loading state, so wait until every client has loaded
 	// before starting the game
 	ENSURE(server.m_State == SERVER_STATE_LOADING);
@@ -1356,6 +1369,8 @@ bool CNetServerWorker::OnRejoined(void* context, CFsmEvent* event)
 		session->SendMessage(&pausedMessage);
 	}
 
+	session->SetLongTimeout(false);
+
 	return true;
 }
 
@@ -1444,10 +1459,20 @@ bool CNetServerWorker::CheckGameLoadStatus(CNetServerSession* changedSession)
 
 void CNetServerWorker::StartGame()
 {
+	for (std::pair<const CStr, PlayerAssignment>& player : m_PlayerAssignments)
+		if (player.second.m_Enabled && player.second.m_PlayerID != -1 && player.second.m_Status == 0)
+		{
+			LOGERROR("Tried to start the game without player \"%s\" being ready!", utf8_from_wstring(player.second.m_Name).c_str());
+			return;
+		}
+
 	m_ServerTurnManager = new CNetServerTurnManager(*this);
 
-	for (const CNetServerSession* session : m_Sessions)
+	for (CNetServerSession* session : m_Sessions)
+	{
 		m_ServerTurnManager->InitialiseClient(session->GetHostID(), 0); // TODO: only for non-observers
+		session->SetLongTimeout(true);
+	}
 
 	m_State = SERVER_STATE_LOADING;
 
@@ -1535,7 +1560,8 @@ void CNetServerWorker::SendHolePunchingMessage(const CStr& ipStr, u16 port)
 
 
 CNetServer::CNetServer(bool useLobbyAuth, int autostartPlayers) :
-	m_Worker(new CNetServerWorker(useLobbyAuth, autostartPlayers))
+	m_Worker(new CNetServerWorker(useLobbyAuth, autostartPlayers)),
+	m_LobbyAuth(useLobbyAuth)
 {
 }
 
@@ -1544,6 +1570,11 @@ CNetServer::~CNetServer()
 	delete m_Worker;
 }
 
+bool CNetServer::UseLobbyAuth() const
+{
+	return m_LobbyAuth;
+}
+
 bool CNetServer::SetupConnection(const u16 port)
 {
 	return m_Worker->SetupConnection(port);
