@@ -1,4 +1,4 @@
-/* Copyright (C) 2015 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -22,10 +22,14 @@
 #include <boost/algorithm/string.hpp>
 
 #include "lib/allocators/shared_ptr.h"
+#include "lib/file/vfs/vfs_path.h"
 #include "ps/CLogger.h"
+#include "ps/CStr.h"
 #include "ps/Filesystem.h"
 #include "ps/ThreadUtil.h"
 
+#include <unordered_set>
+
 typedef std::map<CStr, CConfigValueSet> TConfigMap;
 TConfigMap CConfigDB::m_Map[CFG_LAST];
 VfsPath CConfigDB::m_ConfigFile[CFG_LAST];
@@ -33,6 +37,13 @@ bool CConfigDB::m_HasChanges[CFG_LAST];
 
 static pthread_mutex_t cfgdb_mutex = PTHREAD_MUTEX_INITIALIZER;
 
+// These entries will not be printed to logfiles, so that logfiles can be shared without leaking personal or sensitive data
+static const std::unordered_set<std::string> g_UnloggedEntries = {
+	"lobby.password",
+	"lobby.buddies",
+	"userreport.id" // authentication token for GDPR personal data requests
+};
+
 CConfigDB::CConfigDB()
 {
 	// Recursive mutex needed for WriteFile
@@ -110,6 +121,7 @@ std::string EscapeString(const CStr& str)
 	}
 GETVAL(bool)
 GETVAL(int)
+GETVAL(u32)
 GETVAL(float)
 GETVAL(double)
 GETVAL(std::string)
@@ -367,7 +379,7 @@ bool CConfigDB::Reload(EConfigNamespace ns)
 		{
 			CStr key(header + name);
 			newMap[key] = values;
-			if (key == "lobby.password")
+			if (g_UnloggedEntries.find(key) != g_UnloggedEntries.end())
 				LOGMESSAGE("Loaded config string \"%s\"", key);
 			else
 			{
