@@ -1,4 +1,4 @@
-/* Copyright (C) 2017 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -173,7 +173,6 @@ bool CGame::StartVisualReplay(const OsPath& replayPath)
 	debug_printf("Starting to replay %s\n", replayPath.string8().c_str());
 
 	m_IsVisualReplay = true;
-	ScriptInterface& scriptInterface = m_Simulation2->GetScriptInterface();
 
 	SetTurnManager(new CReplayTurnManager(*m_Simulation2, GetReplayLogger()));
 
@@ -186,6 +185,7 @@ bool CGame::StartVisualReplay(const OsPath& replayPath)
 	std::string line;
 	std::getline(*m_ReplayStream, line);
 
+	const ScriptInterface& scriptInterface = m_Simulation2->GetScriptInterface();
 	JSContext* cx = scriptInterface.GetContext();
 	JSAutoRequest rq(cx);
 
@@ -203,7 +203,7 @@ bool CGame::StartVisualReplay(const OsPath& replayPath)
  **/
 void CGame::RegisterInit(const JS::HandleValue attribs, const std::string& savedState)
 {
-	ScriptInterface& scriptInterface = m_Simulation2->GetScriptInterface();
+	const ScriptInterface& scriptInterface = m_Simulation2->GetScriptInterface();
 	JSContext* cx = scriptInterface.GetContext();
 	JSAutoRequest rq(cx);
 
@@ -301,10 +301,7 @@ PSRETURN CGame::ReallyStartGame()
 		if (!g_AtlasGameLoop->running)
 			m_Simulation2->PreInitGame();
 
-		JS::RootedValue settings(cx);
-		JS::RootedValue tmpInitAttributes(cx, m_Simulation2->GetInitAttributes());
-		m_Simulation2->GetScriptInterface().GetProperty(tmpInitAttributes, "settings", &settings);
-		m_Simulation2->InitGame(settings);
+		m_Simulation2->InitGame();
 	}
 
 	// We need to do an initial Interpolate call to set up all the models etc,
@@ -336,7 +333,6 @@ PSRETURN CGame::ReallyStartGame()
 	if (CProfileManager::IsInitialised())
 		g_Profiler.StructuralReset();
 
-	// Mark terrain as modified so the minimap can repaint (is there a cleaner way of handling this?)
 	g_GameRestarted = true;
 
 	return 0;
@@ -449,7 +445,7 @@ void CGame::CachePlayerColors()
 		if (!cmpPlayer)
 			m_PlayerColors[i] = BrokenColor;
 		else
-			m_PlayerColors[i] = cmpPlayer->GetColor();
+			m_PlayerColors[i] = cmpPlayer->GetDisplayedColor();
 	}
 }
 
