@@ -1,4 +1,4 @@
-/* Copyright (C) 2016 Wildfire Games.
+/* Copyright (C) 2017 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -50,8 +50,8 @@ extern bool g_RenderActors;
 // flag to switch on shadows
 extern bool g_Shadows;
 
-// Force the use of the fixed function for rendering water.
-extern bool g_WaterUgly;
+// If disabled, force the use of the fixed function for rendering water.
+extern bool g_WaterEffects;
 // Add foam and waves near the shores, trails following ships, and other HQ things.
 extern bool g_WaterFancyEffects;
 // Use real depth for water rendering.
@@ -67,6 +67,8 @@ extern bool g_WaterShadows;
 extern bool g_ShadowPCF;
 // flag to switch on particles rendering
 extern bool g_Particles;
+// flag to switch on fog
+extern bool g_Fog;
 // flag to switch on unit silhouettes
 extern bool g_Silhouettes;
 // flag to switch on sky rendering
