@@ -19,7 +19,6 @@
 #define INCLUDED_TEMPLATELOADER
 
 #include "simulation2/system/ParamNode.h"
-#include "scriptinterface/ScriptInterface.h"
 
 enum ETemplatesType
 {
@@ -65,8 +64,6 @@ public:
 	 */
 	std::vector<std::string> FindTemplates(const std::string& path, bool includeSubdirectories, ETemplatesType templatesType) const;
 
-	std::vector<std::string> FindPlaceableTemplates(const std::string& path, bool includeSubdirectories, ETemplatesType templatesType, ScriptInterface& scriptInterface) const;
-
 private:
 	/**
 	 * (Re)loads the given template, regardless of whether it exists already,
