@@ -1,4 +1,4 @@
-/* Copyright (C) 2016 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -25,12 +25,16 @@
 #include "lib/external_libraries/libsdl.h"
 #include "lib/external_libraries/zlib.h"
 #include "lib/file/archive/stream.h"
+#include "lib/os_path.h"
 #include "lib/sysdep/sysdep.h"
 #include "ps/ConfigDB.h"
 #include "ps/Filesystem.h"
 #include "ps/Profiler2.h"
 #include "ps/ThreadUtil.h"
 
+#include <fstream>
+#include <string>
+
 #define DEBUG_UPLOADS 0
 
 /*
@@ -105,6 +109,9 @@ public:
 		// To minimise security risks, don't support redirects
 		curl_easy_setopt(m_Curl, CURLOPT_FOLLOWLOCATION, 0L);
 
+		// Prevent this thread from blocking the engine shutdown for 5 minutes in case the server is unavailable
+		curl_easy_setopt(m_Curl, CURLOPT_CONNECTTIMEOUT, 10L);
+
 		// Set IO callbacks
 		curl_easy_setopt(m_Curl, CURLOPT_WRITEFUNCTION, ReceiveCallback);
 		curl_easy_setopt(m_Curl, CURLOPT_WRITEDATA, this);
@@ -343,6 +350,7 @@ private:
 		ConstructRequestData(*report);
 		m_RequestDataOffset = 0;
 		m_ResponseData.clear();
+		m_ErrorBuffer[0] = '\0';
 
 		curl_easy_setopt(m_Curl, CURLOPT_POSTFIELDSIZE_LARGE, (curl_off_t)m_RequestData.size());
 
@@ -380,7 +388,12 @@ private:
 		}
 		else
 		{
-			SetStatus("failed:" + CStr::FromInt(err) + ":" + m_ErrorBuffer);
+			std::string errorString(m_ErrorBuffer);
+
+			if (errorString.empty())
+				errorString = curl_easy_strerror(err);
+
+			SetStatus("failed:" + CStr::FromInt(err) + ":" + errorString);
 		}
 
 		// We got an unhandled return code or a connection failure;
@@ -569,14 +582,13 @@ std::string CUserReporter::GetStatus()
 	return m_Worker->GetStatus();
 }
 
-
 void CUserReporter::Initialize()
 {
 	ENSURE(!m_Worker); // must only be called once
 
 	std::string userID = LoadUserID();
 	std::string url;
-	CFG_GET_VAL("userreport.url", url);
+	CFG_GET_VAL("userreport.url_upload", url);
 
 	m_Worker = new CUserReporterWorker(userID, url);
 
@@ -607,12 +619,28 @@ void CUserReporter::Update()
 		m_Worker->Update();
 }
 
-void CUserReporter::SubmitReport(const char* type, int version, const std::string& data)
+void CUserReporter::SubmitReport(const std::string& type, int version, const std::string& data, const std::string& dataHumanReadable)
 {
+	// Write to logfile, enabling users to assess privacy concerns before the data is submitted
+	if (!dataHumanReadable.empty())
+	{
+		OsPath path = psLogDir() / OsPath("userreport_" + type + ".txt");
+		std::ofstream stream(OsString(path), std::ofstream::trunc);
+		if (stream)
+		{
+			debug_printf("UserReport written to %s\n", path.string8().c_str());
+			stream << dataHumanReadable << std::endl;
+			stream.close();
+		}
+		else
+			debug_printf("Failed to write UserReport to %s\n", path.string8().c_str());
+	}
+
 	// If not initialised, discard the report
 	if (!m_Worker)
 		return;
 
+	// Actual submit
 	shared_ptr<CUserReport> report(new CUserReport);
 	report->m_Time = time(NULL);
 	report->m_Type = type;
