@@ -1,4 +1,4 @@
-/* Copyright (C) 2013 Wildfire Games.
+/* Copyright (C) 2017 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -36,9 +36,9 @@ ERROR_TYPE(Game_World, MapLoadFailed);
 
 class CGame;
 class CUnitManager;
-class CTerritoryManager;
 class CTerrain;
 class CStrW;
+class CMapReader;
 
 /**
  * CWorld is a general data class containing whatever is needed to accurately represent the world.
@@ -61,10 +61,8 @@ class CWorld
 	 * pointer to the CUnitManager that holds all the units in the world.
 	 **/
 	CUnitManager *m_UnitManager;
-	/**
-	 * pointer to the CTerritoryManager that holds territory matrix for the world.
-	 **/
-	CTerritoryManager *m_TerritoryManager;
+
+	CMapReader* m_MapReader;
 
 public:
 	CWorld(CGame *pGame);
@@ -80,6 +78,11 @@ public:
 	*/
 	void RegisterInitRMS(const CStrW& scriptFile, JSRuntime* rt, JS::HandleValue settings, int playerID);
 
+	/**
+	 * Explicitly delete m_MapReader once the map has finished loading.
+	 **/
+	int DeleteMapReader();
+
 	/**
 	 * Get the pointer to the terrain object.
 	 *
@@ -95,13 +98,6 @@ public:
 	 **/
 	inline CUnitManager &GetUnitManager()
 	{	return *m_UnitManager; }
-	/**
-	 * Get the pointer to the territory manager object.
-	 *
-	 * @return CTerritoryManager * the value of m_TerritoryManager.
-	 **/
-	inline CTerritoryManager *GetTerritoryManager()
-	{	return m_TerritoryManager; }
 };
 
 // rationale: see definition.
