@@ -1,4 +1,4 @@
-/* Copyright (C) 2014 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -19,15 +19,23 @@
 
 // usually defined by main.cpp, used by engine's scripting/ScriptFunctions.cpp,
 // must be included here to placate linker.
-void kill_mainloop()
+
+bool g_GameRestarted;
+
+bool IsQuitRequested()
+{
+	return false;
+}
+
+void QuitEngine()
 {
 }
 
-void restart_mainloop_in_atlas()
+void StartAtlas()
 {
 }
 
-void restart_engine()
+void RestartEngine()
 {
 }
 
