@@ -75,8 +75,6 @@
 #include "renderer/WaterManager.h"
 #include "scriptinterface/ScriptInterface.h"
 
-extern bool g_GameRestarted;
-
 struct SScreenRect
 {
 	GLint x1, y1, x2, y2;
@@ -421,6 +419,7 @@ CRenderer::CRenderer()
 	m_Width = 0;
 	m_Height = 0;
 	m_TerrainRenderMode = SOLID;
+	m_WaterRenderMode = SOLID;
 	m_ModelRenderMode = SOLID;
 	m_ClearColor[0] = m_ClearColor[1] = m_ClearColor[2] = m_ClearColor[3] = 0;
 
@@ -430,7 +429,7 @@ CRenderer::CRenderer()
 	m_Options.m_NoVBO = false;
 	m_Options.m_RenderPath = RP_DEFAULT;
 	m_Options.m_Shadows = false;
-	m_Options.m_WaterUgly = true;
+	m_Options.m_WaterEffects = false;
 	m_Options.m_WaterFancyEffects = false;
 	m_Options.m_WaterRealDepth = false;
 	m_Options.m_WaterRefraction = false;
@@ -442,6 +441,7 @@ CRenderer::CRenderer()
 	m_Options.m_Particles = false;
 	m_Options.m_Silhouettes = false;
 	m_Options.m_PreferGLSL = false;
+	m_Options.m_Fog = false;
 	m_Options.m_ForceAlphaTest = false;
 	m_Options.m_GPUSkinning = false;
 	m_Options.m_SmoothLOS = false;
@@ -581,6 +581,9 @@ void CRenderer::ReloadShaders()
 	if (m_LightEnv)
 		m->globalContext.Add(CStrIntern("LIGHTING_MODEL_" + m_LightEnv->GetLightingModel()), str_1);
 
+	if (m_Options.m_PreferGLSL && m_Options.m_Fog)
+		m->globalContext.Add(str_USE_FOG, str_1);
+
 	m->Model.ModShader = LitRenderModifierPtr(new ShaderRenderModifier());
 
 	bool cpuLighting = (GetRenderPath() == RP_FIXED);
@@ -691,8 +694,8 @@ void CRenderer::SetOptionBool(enum Option opt,bool value)
 			m_Options.m_Shadows = value;
 			MakeShadersDirty();
 			break;
-		case OPT_WATERUGLY:
-			m_Options.m_WaterUgly = value;
+		case OPT_WATEREFFECTS:
+			m_Options.m_WaterEffects = value;
 			break;
 		case OPT_WATERFANCYEFFECTS:
 			m_Options.m_WaterFancyEffects = value;
@@ -721,6 +724,10 @@ void CRenderer::SetOptionBool(enum Option opt,bool value)
 			MakeShadersDirty();
 			RecomputeSystemShaderDefines();
 			break;
+		case OPT_FOG:
+			m_Options.m_Fog = value;
+			MakeShadersDirty();
+			break;
 		case OPT_SILHOUETTES:
 			m_Options.m_Silhouettes = value;
 			break;
@@ -751,8 +758,8 @@ bool CRenderer::GetOptionBool(enum Option opt) const
 			return m_Options.m_NoVBO;
 		case OPT_SHADOWS:
 			return m_Options.m_Shadows;
-		case OPT_WATERUGLY:
-			return m_Options.m_WaterUgly;
+		case OPT_WATEREFFECTS:
+			return m_Options.m_WaterEffects;
 		case OPT_WATERFANCYEFFECTS:
 			return m_Options.m_WaterFancyEffects;
 		case OPT_WATERREALDEPTH:
@@ -769,6 +776,8 @@ bool CRenderer::GetOptionBool(enum Option opt) const
 			return m_Options.m_Particles;
 		case OPT_PREFERGLSL:
 			return m_Options.m_PreferGLSL;
+		case OPT_FOG:
+			return m_Options.m_Fog;
 		case OPT_SILHOUETTES:
 			return m_Options.m_Silhouettes;
 		case OPT_SHOWSKY:
@@ -1396,10 +1405,13 @@ void CRenderer::RenderSilhouettes(const CShaderDefines& context)
 	}
 
 	{
-		PROFILE("render casters");
+		PROFILE("render model casters");
 		m->CallModelRenderers(contextDisplay, CULL_SILHOUETTE_CASTER, 0);
-		// (This won't render transparent objects with SILHOUETTE_CASTER - will
-		// we have any units that need that?)
+	}
+
+	{
+		PROFILE("render transparent casters");
+		m->CallTranspModelRenderers(contextDisplay, CULL_SILHOUETTE_CASTER, 0);
 	}
 
 	// Restore state
@@ -2084,6 +2096,7 @@ Status CRenderer::ReloadChangedFileCB(void* param, const VfsPath& path)
 void CRenderer::MakeShadersDirty()
 {
 	m->ShadersDirty = true;
+	m_WaterManager->m_NeedsReloading = true;
 }
 
 CTextureManager& CRenderer::GetTextureManager()
@@ -2126,6 +2139,11 @@ CFontManager& CRenderer::GetFontManager()
 	return m->fontManager;
 }
 
+ShadowMap& CRenderer::GetShadowMap()
+{
+	return m->shadow;
+}
+
 void CRenderer::ResetState()
 {
 	// Clear all emitters, that were created in previous games
