@@ -56,7 +56,7 @@ struct ScriptInterface_impl
 {
 	ScriptInterface_impl(const char* nativeScopeName, const shared_ptr<ScriptRuntime>& runtime);
 	~ScriptInterface_impl();
-	void Register(const char* name, JSNative fptr, uint nargs);
+	void Register(const char* name, JSNative fptr, uint nargs) const;
 
 	// Take care to keep this declaration before heap rooted members. Destructors of heap rooted
 	// members have to be called before the runtime destructor.
@@ -138,7 +138,7 @@ void ErrorReporter(JSContext* cx, const char* message, JSErrorReport* report)
 
 // Functions in the global namespace:
 
-bool print(JSContext* cx, uint argc, jsval* vp)
+bool print(JSContext* cx, uint argc, JS::Value* vp)
 {
 	JS::CallArgs args = JS::CallArgsFromVp(argc, vp);
 	for (uint i = 0; i < args.length(); ++i)
@@ -153,7 +153,7 @@ bool print(JSContext* cx, uint argc, jsval* vp)
 	return true;
 }
 
-bool logmsg(JSContext* cx, uint argc, jsval* vp)
+bool logmsg(JSContext* cx, uint argc, JS::Value* vp)
 {
 	JS::CallArgs args = JS::CallArgsFromVp(argc, vp);
 	if (args.length() < 1)
@@ -170,7 +170,7 @@ bool logmsg(JSContext* cx, uint argc, jsval* vp)
 	return true;
 }
 
-bool warn(JSContext* cx, uint argc, jsval* vp)
+bool warn(JSContext* cx, uint argc, JS::Value* vp)
 {
 	JS::CallArgs args = JS::CallArgsFromVp(argc, vp);
 	if (args.length() < 1)
@@ -187,7 +187,7 @@ bool warn(JSContext* cx, uint argc, jsval* vp)
 	return true;
 }
 
-bool error(JSContext* cx, uint argc, jsval* vp)
+bool error(JSContext* cx, uint argc, JS::Value* vp)
 {
 	JS::CallArgs args = JS::CallArgsFromVp(argc, vp);
 	if (args.length() < 1)
@@ -204,7 +204,7 @@ bool error(JSContext* cx, uint argc, jsval* vp)
 	return true;
 }
 
-bool deepcopy(JSContext* cx, uint argc, jsval* vp)
+bool deepcopy(JSContext* cx, uint argc, JS::Value* vp)
 {
 	JSAutoRequest rq(cx);
 
@@ -223,7 +223,22 @@ bool deepcopy(JSContext* cx, uint argc, jsval* vp)
 	return true;
 }
 
-bool ProfileStart(JSContext* cx, uint argc, jsval* vp)
+bool deepfreeze(JSContext* cx, uint argc, JS::Value* vp)
+{
+	JS::CallArgs args = JS::CallArgsFromVp(argc, vp);
+
+	if (args.length() != 1 || !args.get(0).isObject())
+	{
+		JS_ReportError(cx, "deepfreeze requires exactly one object as an argument.");
+		return false;
+	}
+
+	ScriptInterface::GetScriptInterfaceAndCBData(cx)->pScriptInterface->FreezeObject(args.get(0), true);
+	args.rval().set(args.get(0));
+	return true;
+}
+
+bool ProfileStart(JSContext* cx, uint argc, JS::Value* vp)
 {
 	const char* name = "(ProfileStart)";
 
@@ -252,7 +267,7 @@ bool ProfileStart(JSContext* cx, uint argc, jsval* vp)
 	return true;
 }
 
-bool ProfileStop(JSContext* UNUSED(cx), uint UNUSED(argc), jsval* vp)
+bool ProfileStop(JSContext* UNUSED(cx), uint UNUSED(argc), JS::Value* vp)
 {
 	JS::CallReceiver rec = JS::CallReceiverFromVp(vp);
 	if (CProfileManager::IsInitialised() && ThreadUtil::IsMainThread())
@@ -264,7 +279,7 @@ bool ProfileStop(JSContext* UNUSED(cx), uint UNUSED(argc), jsval* vp)
 	return true;
 }
 
-bool ProfileAttribute(JSContext* cx, uint argc, jsval* vp)
+bool ProfileAttribute(JSContext* cx, uint argc, JS::Value* vp)
 {
 	const char* name = "(ProfileAttribute)";
 
@@ -308,7 +323,7 @@ static double generate_uniform_real(boost::rand48& rng, double min, double max)
 	}
 }
 
-bool Math_random(JSContext* cx, uint UNUSED(argc), jsval* vp)
+bool Math_random(JSContext* cx, uint UNUSED(argc), JS::Value* vp)
 {
 	JS::CallReceiver rec = JS::CallReceiverFromVp(vp);
 	double r;
@@ -374,7 +389,8 @@ ScriptInterface_impl::ScriptInterface_impl(const char* nativeScopeName, const sh
 	JS_DefineFunction(m_cx, globalRootedVal, "log",   ::logmsg,       1, JSPROP_ENUMERATE | JSPROP_READONLY | JSPROP_PERMANENT);
 	JS_DefineFunction(m_cx, globalRootedVal, "warn",  ::warn,         1, JSPROP_ENUMERATE | JSPROP_READONLY | JSPROP_PERMANENT);
 	JS_DefineFunction(m_cx, globalRootedVal, "error", ::error,        1, JSPROP_ENUMERATE | JSPROP_READONLY | JSPROP_PERMANENT);
-	JS_DefineFunction(m_cx, globalRootedVal, "deepcopy", ::deepcopy,  1, JSPROP_ENUMERATE | JSPROP_READONLY | JSPROP_PERMANENT);
+	JS_DefineFunction(m_cx, globalRootedVal, "clone", ::deepcopy,        1, JSPROP_ENUMERATE | JSPROP_READONLY | JSPROP_PERMANENT);
+	JS_DefineFunction(m_cx, globalRootedVal, "deepfreeze", ::deepfreeze, 1, JSPROP_ENUMERATE | JSPROP_READONLY | JSPROP_PERMANENT);
 
 	Register("ProfileStart", ::ProfileStart, 1);
 	Register("ProfileStop", ::ProfileStop, 0);
@@ -393,7 +409,7 @@ ScriptInterface_impl::~ScriptInterface_impl()
 	JS_DestroyContext(m_cx);
 }
 
-void ScriptInterface_impl::Register(const char* name, JSNative fptr, uint nargs)
+void ScriptInterface_impl::Register(const char* name, JSNative fptr, uint nargs) const
 {
 	JSAutoRequest rq(m_cx);
 	JS::RootedObject nativeScope(m_cx, m_nativeScope);
@@ -489,7 +505,7 @@ bool ScriptInterface::ReplaceNondeterministicRNG(boost::rand48& rng)
 	return false;
 }
 
-void ScriptInterface::Register(const char* name, JSNative fptr, size_t nargs)
+void ScriptInterface::Register(const char* name, JSNative fptr, size_t nargs) const
 {
 	m->Register(name, fptr, (uint)nargs);
 }
@@ -580,17 +596,12 @@ bool ScriptInterface::CallFunction_(JS::HandleValue val, const char* name, JS::H
 	return ok;
 }
 
-jsval ScriptInterface::GetGlobalObject()
+JS::Value ScriptInterface::GetGlobalObject() const
 {
 	JSAutoRequest rq(m->m_cx);
 	return JS::ObjectValue(*JS::CurrentGlobalOrNull(m->m_cx));
 }
 
-JSClass* ScriptInterface::GetGlobalClass()
-{
-	return &global_class;
-}
-
 bool ScriptInterface::SetGlobal_(const char* name, JS::HandleValue value, bool replace)
 {
 	JSAutoRequest rq(m->m_cx);
@@ -612,7 +623,7 @@ bool ScriptInterface::SetGlobal_(const char* name, JS::HandleValue value, bool r
 	return ok;
 }
 
-bool ScriptInterface::SetProperty_(JS::HandleValue obj, const char* name, JS::HandleValue value, bool constant, bool enumerate)
+bool ScriptInterface::SetProperty_(JS::HandleValue obj, const char* name, JS::HandleValue value, bool constant, bool enumerate) const
 {
 	JSAutoRequest rq(m->m_cx);
 	uint attrs = 0;
@@ -630,7 +641,7 @@ bool ScriptInterface::SetProperty_(JS::HandleValue obj, const char* name, JS::Ha
 	return true;
 }
 
-bool ScriptInterface::SetProperty_(JS::HandleValue obj, const wchar_t* name, JS::HandleValue value, bool constant, bool enumerate)
+bool ScriptInterface::SetProperty_(JS::HandleValue obj, const wchar_t* name, JS::HandleValue value, bool constant, bool enumerate) const
 {
 	JSAutoRequest rq(m->m_cx);
 	uint attrs = 0;
@@ -649,7 +660,7 @@ bool ScriptInterface::SetProperty_(JS::HandleValue obj, const wchar_t* name, JS:
 	return true;
 }
 
-bool ScriptInterface::SetPropertyInt_(JS::HandleValue obj, int name, JS::HandleValue value, bool constant, bool enumerate)
+bool ScriptInterface::SetPropertyInt_(JS::HandleValue obj, int name, JS::HandleValue value, bool constant, bool enumerate) const
 {
 	JSAutoRequest rq(m->m_cx);
 	uint attrs = 0;
@@ -1092,18 +1103,7 @@ void* ScriptInterface::GetPrivate(JS::HandleObject obj)
 	return JS_GetPrivate(obj);
 }
 
-void ScriptInterface::MaybeGC()
-{
-	JS_MaybeGC(m->m_cx);
-}
-
-void ScriptInterface::ForceGC()
-{
-	PROFILE2("JS_GC");
-	JS_GC(this->GetJSRuntime());
-}
-
-JS::Value ScriptInterface::CloneValueFromOtherContext(ScriptInterface& otherContext, JS::HandleValue val)
+JS::Value ScriptInterface::CloneValueFromOtherContext(const ScriptInterface& otherContext, JS::HandleValue val) const
 {
 	PROFILE("CloneValueFromOtherContext");
 	JSAutoRequest rq(m->m_cx);
@@ -1124,7 +1124,7 @@ ScriptInterface::StructuredClone::~StructuredClone()
 		JS_ClearStructuredClone(m_Data, m_Size, NULL, NULL);
 }
 
-shared_ptr<ScriptInterface::StructuredClone> ScriptInterface::WriteStructuredClone(JS::HandleValue v)
+shared_ptr<ScriptInterface::StructuredClone> ScriptInterface::WriteStructuredClone(JS::HandleValue v) const
 {
 	JSAutoRequest rq(m->m_cx);
 	u64* data = NULL;
@@ -1141,7 +1141,7 @@ shared_ptr<ScriptInterface::StructuredClone> ScriptInterface::WriteStructuredClo
 	return ret;
 }
 
-void ScriptInterface::ReadStructuredClone(const shared_ptr<ScriptInterface::StructuredClone>& ptr, JS::MutableHandleValue ret)
+void ScriptInterface::ReadStructuredClone(const shared_ptr<ScriptInterface::StructuredClone>& ptr, JS::MutableHandleValue ret) const
 {
 	JSAutoRequest rq(m->m_cx);
 	JS_ReadStructuredClone(m->m_cx, ptr->m_Data, ptr->m_Size, JS_STRUCTURED_CLONE_VERSION, ret, NULL, NULL);
