@@ -35,8 +35,8 @@
 	virtual int GetType() const { return MT_##name; } \
 	virtual const char* GetScriptHandlerName() const { return "On" #name; } \
 	virtual const char* GetScriptGlobalHandlerName() const { return "OnGlobal" #name; } \
-	virtual JS::Value ToJSVal(ScriptInterface& scriptInterface) const; \
-	static CMessage* FromJSVal(ScriptInterface&, JS::HandleValue val);
+	virtual JS::Value ToJSVal(const ScriptInterface& scriptInterface) const; \
+	static CMessage* FromJSVal(const ScriptInterface&, JS::HandleValue val);
 
 class SceneCollector;
 class CFrustum;
@@ -489,6 +489,22 @@ public:
 	std::vector<std::wstring> valueNames;
 };
 
+/**
+ * Sent by atlas if the playercolor has been changed.
+ */
+class CMessagePlayerColorChanged : public CMessage
+{
+public:
+	DEFAULT_MESSAGE_IMPL(PlayerColorChanged)
+
+	CMessagePlayerColorChanged(player_id_t player) :
+		player(player)
+	{
+	}
+
+	player_id_t player;
+};
+
 /**
  * Sent by aura and tech managers when a value of a certain template's component is changed
  */
