@@ -1,4 +1,4 @@
-/* Copyright (C) 2017 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -161,7 +161,10 @@ public:
 		SerializationTestState* primaryStateBefore, SerializationTestState* primaryStateAfter,
 		SerializationTestState* secondaryStateBefore, SerializationTestState* secondaryStateAfter);
 
-	static std::vector<SimulationCommand> CloneCommandsFromOtherContext(ScriptInterface& oldScript, ScriptInterface& newScript,
+	void InitRNGSeedSimulation();
+	void InitRNGSeedAI();
+
+	static std::vector<SimulationCommand> CloneCommandsFromOtherContext(const ScriptInterface& oldScript, const ScriptInterface& newScript,
 		const std::vector<SimulationCommand>& commands)
 	{
 		JSContext* cxOld = oldScript.GetContext();
@@ -334,6 +337,28 @@ void CSimulation2Impl::ReportSerializationFailure(
 	debug_warn(L"Serialization test failure");
 }
 
+void CSimulation2Impl::InitRNGSeedSimulation()
+{
+	u32 seed = 0;
+	if (!m_ComponentManager.GetScriptInterface().HasProperty(m_MapSettings, "Seed") ||
+	    !m_ComponentManager.GetScriptInterface().GetProperty(m_MapSettings, "Seed", seed))
+		LOGWARNING("CSimulation2Impl::InitRNGSeedSimulation: No seed value specified - using %d", seed);
+
+	m_ComponentManager.SetRNGSeed(seed);
+}
+
+void CSimulation2Impl::InitRNGSeedAI()
+{
+	u32 seed = 0;
+	if (!m_ComponentManager.GetScriptInterface().HasProperty(m_MapSettings, "AISeed") ||
+	    !m_ComponentManager.GetScriptInterface().GetProperty(m_MapSettings, "AISeed", seed))
+		LOGWARNING("CSimulation2Impl::InitRNGSeedAI: No seed value specified - using %d", seed);
+
+	CmpPtr<ICmpAIManager> cmpAIManager(m_SimContext, SYSTEM_ENTITY);
+	if (cmpAIManager)
+		cmpAIManager->SetRNGSeed(seed);
+}
+
 void CSimulation2Impl::Update(int turnLength, const std::vector<SimulationCommand>& commands)
 {
 	PROFILE3("sim update");
@@ -359,7 +384,7 @@ void CSimulation2Impl::Update(int turnLength, const std::vector<SimulationComman
 	const bool serializationTestHash = true; // set true to save and compare hash of state
 
 	SerializationTestState primaryStateBefore;
-	ScriptInterface& scriptInterface = m_ComponentManager.GetScriptInterface();
+	const ScriptInterface& scriptInterface = m_ComponentManager.GetScriptInterface();
 
 	const bool startRejoinTest = (int64_t) m_RejoinTestTurn == m_TurnNumber;
 	if (startRejoinTest)
@@ -410,7 +435,7 @@ void CSimulation2Impl::Update(int turnLength, const std::vector<SimulationComman
 		// Load the map into the secondary simulation
 
 		LDR_BeginRegistering();
-		CMapReader* mapReader = new CMapReader; // automatically deletes itself
+		std::unique_ptr<CMapReader> mapReader(new CMapReader);
 
 		std::string mapType;
 		scriptInterface.GetProperty(m_InitAttributes, "mapType", mapType);
@@ -712,12 +737,17 @@ void CSimulation2::PreInitGame()
 	GetScriptInterface().CallFunctionVoid(global, "PreInitGame");
 }
 
-void CSimulation2::InitGame(JS::HandleValue data)
+void CSimulation2::InitGame()
 {
 	JSContext* cx = GetScriptInterface().GetContext();
 	JSAutoRequest rq(cx);
 	JS::RootedValue global(cx, GetScriptInterface().GetGlobalObject());
-	GetScriptInterface().CallFunctionVoid(global, "InitGame", data);
+
+	JS::RootedValue settings(cx);
+	JS::RootedValue tmpInitAttributes(cx, GetInitAttributes());
+	GetScriptInterface().GetProperty(tmpInitAttributes, "settings", &settings);
+
+	GetScriptInterface().CallFunctionVoid(global, "InitGame", settings);
 }
 
 void CSimulation2::Update(int turnLength)
@@ -793,12 +823,8 @@ void CSimulation2::SetMapSettings(JS::HandleValue settings)
 {
 	m->m_MapSettings = settings;
 
-	u32 seed = 0;
-	if (!m->m_ComponentManager.GetScriptInterface().HasProperty(m->m_MapSettings, "Seed") ||
-	    !m->m_ComponentManager.GetScriptInterface().GetProperty(m->m_MapSettings, "Seed", seed))
-		LOGWARNING("CSimulation2::SetInitAttributes: No seed value specified - using %d", seed);
-
-	m->m_ComponentManager.SetRNGSeed(seed);
+	m->InitRNGSeedSimulation();
+	m->InitRNGSeedAI();
 }
 
 std::string CSimulation2::GetMapSettingsString()
@@ -949,7 +975,7 @@ std::string CSimulation2::GetMapSizes()
 
 std::string CSimulation2::GetAIData()
 {
-	ScriptInterface& scriptInterface = GetScriptInterface();
+	const ScriptInterface& scriptInterface = GetScriptInterface();
 	JSContext* cx = scriptInterface.GetContext();
 	JSAutoRequest rq(cx);
 	JS::RootedValue aiData(cx, ICmpAIManager::GetAIs(scriptInterface));
