@@ -1,4 +1,4 @@
-/* Copyright (C) 2017 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -23,7 +23,9 @@
 #include "ps/CLogger.h"
 #include "simulation2/MessageTypes.h"
 #include "simulation2/components/ICmpObstructionManager.h"
+#include "simulation2/components/ICmpTerrain.h"
 #include "simulation2/components/ICmpUnitMotion.h"
+#include "simulation2/components/ICmpWaterManager.h"
 #include "simulation2/serialization/SerializeTemplates.h"
 
 /**
@@ -166,6 +168,9 @@ public:
 			"<element name='BlockConstruction' a:help='Whether players should be unable to begin constructing buildings placed on top of this entity'>"
 				"<data type='boolean'/>"
 			"</element>"
+			"<element name='DeleteUponConstruction' a:help='Whether this entity should be deleted when construction on a buildings placed on top of this entity is started.'>"
+				"<data type='boolean'/>"
+			"</element>"
 			"<element name='DisableBlockMovement' a:help='If true, BlockMovement will be overridden and treated as false. (This is a special case to handle foundations)'>"
 				"<data type='boolean'/>"
 			"</element>"
@@ -193,6 +198,8 @@ public:
 			m_TemplateFlags |= ICmpObstructionManager::FLAG_BLOCK_FOUNDATION;
 		if (paramNode.GetChild("BlockConstruction").ToBool())
 			m_TemplateFlags |= ICmpObstructionManager::FLAG_BLOCK_CONSTRUCTION;
+		if (paramNode.GetChild("DeleteUponConstruction").ToBool())
+			m_TemplateFlags |= ICmpObstructionManager::FLAG_DELETE_UPON_CONSTRUCTION;
 
 		m_Flags = m_TemplateFlags;
 		if (paramNode.GetChild("DisableBlockMovement").ToBool())
@@ -520,6 +527,25 @@ public:
 		return m_ControlPersist;
 	}
 
+	virtual bool CheckShorePlacement() const
+	{
+		ICmpObstructionManager::ObstructionSquare s;
+		if (!GetObstructionSquare(s))
+			return false;
+
+		CFixedVector2D front = CFixedVector2D(s.x, s.z) + s.v.Multiply(s.hh);
+		CFixedVector2D  back = CFixedVector2D(s.x, s.z) - s.v.Multiply(s.hh);
+
+		CmpPtr<ICmpTerrain> cmpTerrain(GetSystemEntity());
+		CmpPtr<ICmpWaterManager> cmpWaterManager(GetSystemEntity());
+		if (!cmpTerrain || !cmpWaterManager)
+			return false;
+
+		// Keep these constants in agreement with the pathfinder.
+		return cmpWaterManager->GetWaterLevel(front.X, front.Y) - cmpTerrain->GetGroundLevel(front.X, front.Y) > fixed::FromInt(1) &&
+		       cmpWaterManager->GetWaterLevel( back.X,  back.Y) - cmpTerrain->GetGroundLevel( back.X,  back.Y) < fixed::FromInt(2);
+	}
+
 	virtual EFoundationCheck CheckFoundation(const std::string& className) const
 	{
 		return  CheckFoundation(className, false);
@@ -594,7 +620,7 @@ public:
 			return !cmpObstructionManager->TestStaticShape(filter, pos.X, pos.Y, cmpPosition->GetRotation().Y, m_Size0, m_Size1, NULL );
 	}
 
-	virtual std::vector<entity_id_t> GetUnitCollisions() const
+	virtual std::vector<entity_id_t> GetEntitiesByFlags(flags_t flags) const
 	{
 		std::vector<entity_id_t> ret;
 
@@ -602,11 +628,6 @@ public:
 		if (!cmpObstructionManager)
 			return ret; // error
 
-		// There are four 'block' flags: construction, foundation, movement,
-		// and pathfinding. Structures have all of these flags, while units
-		// block only movement and construction.
-		flags_t flags = ICmpObstructionManager::FLAG_BLOCK_CONSTRUCTION;
-
 		// Ignore collisions within the same control group, or with other shapes that don't match the filter.
 		// Note that, since the control group for each entity defaults to the entity's ID, this is typically
 		// equivalent to only ignoring the entity's own shape and other shapes that don't match the filter.
@@ -616,11 +637,22 @@ public:
 		if (!GetObstructionSquare(square))
 			return ret; // error
 
-		cmpObstructionManager->GetUnitsOnObstruction(square, ret, filter);
+		cmpObstructionManager->GetUnitsOnObstruction(square, ret, filter, false);
+		cmpObstructionManager->GetStaticObstructionsOnObstruction(square, ret, filter);
 
 		return ret;
 	}
 
+	virtual std::vector<entity_id_t> GetEntitiesBlockingConstruction() const
+	{
+		return GetEntitiesByFlags(ICmpObstructionManager::FLAG_BLOCK_CONSTRUCTION);
+	}
+
+	virtual std::vector<entity_id_t> GetEntitiesDeletedUponConstruction() const
+	{
+		return GetEntitiesByFlags(ICmpObstructionManager::FLAG_DELETE_UPON_CONSTRUCTION);
+	}
+
 	virtual void SetMovingFlag(bool enabled)
 	{
 		m_Moving = enabled;
