@@ -1,4 +1,4 @@
-/* Copyright (C) 2017 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -21,6 +21,7 @@
 #include "ICmpObstructionManager.h"
 
 #include "ICmpTerrain.h"
+#include "ICmpPosition.h"
 
 #include "simulation2/MessageTypes.h"
 #include "simulation2/helpers/Geometry.h"
@@ -464,6 +465,8 @@ public:
 		}
 	}
 
+	virtual fixed DistanceToPoint(entity_id_t ent, entity_pos_t px, entity_pos_t pz) const;
+
 	virtual bool TestLine(const IObstructionTestFilter& filter, entity_pos_t x0, entity_pos_t z0, entity_pos_t x1, entity_pos_t z1, entity_pos_t r, bool relaxClearanceForUnits = false) const;
 	virtual bool TestStaticShape(const IObstructionTestFilter& filter, entity_pos_t x, entity_pos_t z, entity_pos_t a, entity_pos_t w, entity_pos_t h, std::vector<entity_id_t>* out) const;
 	virtual bool TestUnitShape(const IObstructionTestFilter& filter, entity_pos_t x, entity_pos_t z, entity_pos_t r, std::vector<entity_id_t>* out) const;
@@ -473,6 +476,7 @@ public:
 	virtual void GetUnitObstructionsInRange(const IObstructionTestFilter& filter, entity_pos_t x0, entity_pos_t z0, entity_pos_t x1, entity_pos_t z1, std::vector<ObstructionSquare>& squares) const;
 	virtual void GetStaticObstructionsInRange(const IObstructionTestFilter& filter, entity_pos_t x0, entity_pos_t z0, entity_pos_t x1, entity_pos_t z1, std::vector<ObstructionSquare>& squares) const;
 	virtual void GetUnitsOnObstruction(const ObstructionSquare& square, std::vector<entity_id_t>& out, const IObstructionTestFilter& filter, bool strict = false) const;
+	virtual void GetStaticObstructionsOnObstruction(const ObstructionSquare& square, std::vector<entity_id_t>& out, const IObstructionTestFilter& filter) const;
 
 	virtual void SetPassabilityCircular(bool enabled)
 	{
@@ -653,6 +657,20 @@ private:
 
 REGISTER_COMPONENT_TYPE(ObstructionManager)
 
+fixed CCmpObstructionManager::DistanceToPoint(entity_id_t ent, entity_pos_t px, entity_pos_t pz) const
+{
+	CmpPtr<ICmpPosition> cmpPosition(GetSimContext(), ent);
+	if (!cmpPosition || !cmpPosition->IsInWorld())
+		return fixed::FromInt(-1);
+
+	ObstructionSquare s;
+	CmpPtr<ICmpObstruction> cmpObstruction(GetSimContext(), ent);
+	if (!cmpObstruction || !cmpObstruction->GetObstructionSquare(s))
+		return (CFixedVector2D(px, pz) - cmpPosition->GetPosition2D()).Length();
+
+	return Geometry::DistanceToSquare(CFixedVector2D(px - s.x, pz - s.z), s.u, s.v, CFixedVector2D(s.hw, s.hh));
+}
+
 bool CCmpObstructionManager::TestLine(const IObstructionTestFilter& filter, entity_pos_t x0, entity_pos_t z0, entity_pos_t x1, entity_pos_t z1, entity_pos_t r, bool relaxClearanceForUnits) const
 {
 	PROFILE("TestLine");
@@ -671,9 +689,9 @@ bool CCmpObstructionManager::TestLine(const IObstructionTestFilter& filter, enti
 
 	std::vector<entity_id_t> unitShapes;
 	m_UnitSubdivision.GetInRange(unitShapes, posMin, posMax);
-	for (size_t i = 0; i < unitShapes.size(); ++i)
+	for (const entity_id_t& shape : unitShapes)
 	{
-		std::map<u32, UnitShape>::const_iterator it = m_UnitShapes.find(unitShapes[i]);
+		std::map<u32, UnitShape>::const_iterator it = m_UnitShapes.find(shape);
 		ENSURE(it != m_UnitShapes.end());
 
 		if (!filter.TestShape(UNIT_INDEX_TO_TAG(it->first), it->second.flags, it->second.group, INVALID_ENTITY))
@@ -687,9 +705,9 @@ bool CCmpObstructionManager::TestLine(const IObstructionTestFilter& filter, enti
 
 	std::vector<entity_id_t> staticShapes;
 	m_StaticSubdivision.GetInRange(staticShapes, posMin, posMax);
-	for (size_t i = 0; i < staticShapes.size(); ++i)
+	for (const entity_id_t& shape : staticShapes)
 	{
-		std::map<u32, StaticShape>::const_iterator it = m_StaticShapes.find(staticShapes[i]);
+		std::map<u32, StaticShape>::const_iterator it = m_StaticShapes.find(shape);
 		ENSURE(it != m_StaticShapes.end());
 
 		if (!filter.TestShape(STATIC_INDEX_TO_TAG(it->first), it->second.flags, it->second.group, it->second.group2))
@@ -710,8 +728,6 @@ bool CCmpObstructionManager::TestStaticShape(const IObstructionTestFilter& filte
 {
 	PROFILE("TestStaticShape");
 
-	// TODO: should use the subdivision stuff here, if performance is non-negligible
-
 	if (out)
 		out->clear();
 
@@ -721,12 +737,12 @@ bool CCmpObstructionManager::TestStaticShape(const IObstructionTestFilter& filte
 	CFixedVector2D v(s, c);
 	CFixedVector2D center(x, z);
 	CFixedVector2D halfSize(w/2, h/2);
+	CFixedVector2D corner1 = u.Multiply(halfSize.X) + v.Multiply(halfSize.Y);
+	CFixedVector2D corner2 = u.Multiply(halfSize.X) - v.Multiply(halfSize.Y);
 
 	// Check that all corners are within the world (which means the whole shape must be)
-	if (!IsInWorld(center + u.Multiply(halfSize.X) + v.Multiply(halfSize.Y)) ||
-		!IsInWorld(center + u.Multiply(halfSize.X) - v.Multiply(halfSize.Y)) ||
-		!IsInWorld(center - u.Multiply(halfSize.X) + v.Multiply(halfSize.Y)) ||
-		!IsInWorld(center - u.Multiply(halfSize.X) - v.Multiply(halfSize.Y)))
+	if (!IsInWorld(center + corner1) || !IsInWorld(center + corner2) ||
+	    !IsInWorld(center - corner1) || !IsInWorld(center - corner2))
 	{
 		if (out)
 			out->push_back(INVALID_ENTITY); // no entity ID, so just push an arbitrary marker
@@ -734,8 +750,18 @@ bool CCmpObstructionManager::TestStaticShape(const IObstructionTestFilter& filte
 			return true;
 	}
 
-	for (std::map<u32, UnitShape>::const_iterator it = m_UnitShapes.begin(); it != m_UnitShapes.end(); ++it)
+	fixed bbHalfWidth = std::max(corner1.X.Absolute(), corner2.X.Absolute());
+	fixed bbHalfHeight = std::max(corner1.Y.Absolute(), corner2.Y.Absolute());
+	CFixedVector2D posMin(x - bbHalfWidth, z - bbHalfHeight);
+	CFixedVector2D posMax(x + bbHalfWidth, z + bbHalfHeight);
+
+	std::vector<entity_id_t> unitShapes;
+	m_UnitSubdivision.GetInRange(unitShapes, posMin, posMax);
+	for (entity_id_t& shape : unitShapes)
 	{
+		std::map<u32, UnitShape>::const_iterator it = m_UnitShapes.find(shape);
+		ENSURE(it != m_UnitShapes.end());
+
 		if (!filter.TestShape(UNIT_INDEX_TO_TAG(it->first), it->second.flags, it->second.group, INVALID_ENTITY))
 			continue;
 
@@ -750,8 +776,13 @@ bool CCmpObstructionManager::TestStaticShape(const IObstructionTestFilter& filte
 		}
 	}
 
-	for (std::map<u32, StaticShape>::const_iterator it = m_StaticShapes.begin(); it != m_StaticShapes.end(); ++it)
+	std::vector<entity_id_t> staticShapes;
+	m_StaticSubdivision.GetInRange(staticShapes, posMin, posMax);
+	for (entity_id_t& shape : staticShapes)
 	{
+		std::map<u32, StaticShape>::const_iterator it = m_StaticShapes.find(shape);
+		ENSURE(it != m_StaticShapes.end());
+
 		if (!filter.TestShape(STATIC_INDEX_TO_TAG(it->first), it->second.flags, it->second.group, it->second.group2))
 			continue;
 
@@ -778,8 +809,6 @@ bool CCmpObstructionManager::TestUnitShape(const IObstructionTestFilter& filter,
 {
 	PROFILE("TestUnitShape");
 
-	// TODO: should use the subdivision stuff here, if performance is non-negligible
-
 	// Check that the shape is within the world
 	if (!IsInWorld(x, z, clearance))
 	{
@@ -790,9 +819,16 @@ bool CCmpObstructionManager::TestUnitShape(const IObstructionTestFilter& filter,
 	}
 
 	CFixedVector2D center(x, z);
+	CFixedVector2D posMin(x - clearance, z - clearance);
+	CFixedVector2D posMax(x + clearance, z + clearance);
 
-	for (std::map<u32, UnitShape>::const_iterator it = m_UnitShapes.begin(); it != m_UnitShapes.end(); ++it)
+	std::vector<entity_id_t> unitShapes;
+	m_UnitSubdivision.GetInRange(unitShapes, posMin, posMax);
+	for (const entity_id_t& shape : unitShapes)
 	{
+		std::map<u32, UnitShape>::const_iterator it = m_UnitShapes.find(shape);
+		ENSURE(it != m_UnitShapes.end());
+
 		if (!filter.TestShape(UNIT_INDEX_TO_TAG(it->first), it->second.flags, it->second.group, INVALID_ENTITY))
 			continue;
 
@@ -811,8 +847,13 @@ bool CCmpObstructionManager::TestUnitShape(const IObstructionTestFilter& filter,
 		}
 	}
 
-	for (std::map<u32, StaticShape>::const_iterator it = m_StaticShapes.begin(); it != m_StaticShapes.end(); ++it)
+	std::vector<entity_id_t> staticShapes;
+	m_StaticSubdivision.GetInRange(staticShapes, posMin, posMax);
+	for (const entity_id_t& shape : staticShapes)
 	{
+		std::map<u32, StaticShape>::const_iterator it = m_StaticShapes.find(shape);
+		ENSURE(it != m_StaticShapes.end());
+
 		if (!filter.TestShape(STATIC_INDEX_TO_TAG(it->first), it->second.flags, it->second.group, it->second.group2))
 			continue;
 
@@ -850,7 +891,7 @@ void CCmpObstructionManager::Rasterize(Grid<NavcellData>& grid, const std::vecto
 		{
 		case PathfinderPassability::PATHFINDING:
 		{
-			auto it = pathfindingMasks.find(passability.m_Clearance);
+			std::map<entity_pos_t, u16>::iterator it = pathfindingMasks.find(passability.m_Clearance);
 			if (it == pathfindingMasks.end())
 				pathfindingMasks[passability.m_Clearance] = passability.m_Mask;
 			else
@@ -939,7 +980,7 @@ void CCmpObstructionManager::GetUnitObstructionsInRange(const IObstructionTestFi
 	m_UnitSubdivision.GetInRange(unitShapes, CFixedVector2D(x0, z0), CFixedVector2D(x1, z1));
 	for (entity_id_t& unitShape : unitShapes)
 	{
-		auto it = m_UnitShapes.find(unitShape);
+		std::map<u32, UnitShape>::const_iterator it = m_UnitShapes.find(unitShape);
 		ENSURE(it != m_UnitShapes.end());
 
 		if (!filter.TestShape(UNIT_INDEX_TO_TAG(it->first), it->second.flags, it->second.group, INVALID_ENTITY))
@@ -967,7 +1008,7 @@ void CCmpObstructionManager::GetStaticObstructionsInRange(const IObstructionTest
 	m_StaticSubdivision.GetInRange(staticShapes, CFixedVector2D(x0, z0), CFixedVector2D(x1, z1));
 	for (entity_id_t& staticShape : staticShapes)
 	{
-		auto it = m_StaticShapes.find(staticShape);
+		std::map<u32, StaticShape>::const_iterator it = m_StaticShapes.find(staticShape);
 		ENSURE(it != m_StaticShapes.end());
 
 		if (!filter.TestShape(STATIC_INDEX_TO_TAG(it->first), it->second.flags, it->second.group, it->second.group2))
@@ -990,7 +1031,7 @@ void CCmpObstructionManager::GetUnitsOnObstruction(const ObstructionSquare& squa
 	PROFILE("GetUnitsOnObstruction");
 
 	// In order to avoid getting units on impassable cells, we want to find all
-	// units s.t. the RasterizeRectWithClearance of the building's shape with the
+	// units subject to the RasterizeRectWithClearance of the building's shape with the
 	// unit's clearance covers the navcell the unit is on.
 
 	std::vector<entity_id_t> unitShapes;
@@ -1004,7 +1045,7 @@ void CCmpObstructionManager::GetUnitsOnObstruction(const ObstructionSquare& squa
 
 	for (const u32& unitShape : unitShapes)
 	{
-		auto it = m_UnitShapes.find(unitShape);
+		std::map<u32, UnitShape>::const_iterator it = m_UnitShapes.find(unitShape);
 		ENSURE(it != m_UnitShapes.end());
 
 		const UnitShape& shape = it->second;
@@ -1046,6 +1087,40 @@ void CCmpObstructionManager::GetUnitsOnObstruction(const ObstructionSquare& squa
 	}
 }
 
+void CCmpObstructionManager::GetStaticObstructionsOnObstruction(const ObstructionSquare& square, std::vector<entity_id_t>& out, const IObstructionTestFilter& filter) const
+{
+	PROFILE("GetStaticObstructionsOnObstruction");
+
+	std::vector<entity_id_t> staticShapes;
+	CFixedVector2D center(square.x, square.z);
+	CFixedVector2D expandedBox = Geometry::GetHalfBoundingBox(square.u, square.v, CFixedVector2D(square.hw, square.hh));
+	m_StaticSubdivision.GetInRange(staticShapes, center - expandedBox, center + expandedBox);
+
+	for (const u32& staticShape : staticShapes)
+	{
+		std::map<u32, StaticShape>::const_iterator it = m_StaticShapes.find(staticShape);
+		ENSURE(it != m_StaticShapes.end());
+
+		const StaticShape& shape = it->second;
+
+		if (!filter.TestShape(STATIC_INDEX_TO_TAG(staticShape), shape.flags, shape.group, shape.group2))
+			continue;
+
+		if (Geometry::TestSquareSquare(
+		    center,
+		    square.u,
+		    square.v,
+		    CFixedVector2D(square.hw, square.hh),
+		    CFixedVector2D(shape.x, shape.z),
+		    shape.u,
+		    shape.v,
+		    CFixedVector2D(shape.hw, shape.hh)))
+		{
+			out.push_back(shape.entity);
+		}
+	}
+}
+
 void CCmpObstructionManager::RenderSubmit(SceneCollector& collector)
 {
 	if (!m_DebugOverlayEnabled)
