@@ -1,4 +1,4 @@
-/* Copyright (C) 2017 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -77,6 +77,7 @@ class CCmpRallyPointRenderer : public ICmpRallyPointRenderer
 public:
 	static void ClassInit(CComponentManager& componentManager)
 	{
+		componentManager.SubscribeGloballyToMessageType(MT_PlayerColorChanged);
 		componentManager.SubscribeToMessageType(MT_OwnershipChanged);
 		componentManager.SubscribeToMessageType(MT_TurnStart);
 		componentManager.SubscribeToMessageType(MT_Destroy);
@@ -137,7 +138,6 @@ public:
 				"<LineThickness>0.75</LineThickness>"
 				"<LineStartCap>round</LineStartCap>"
 				"<LineEndCap>square</LineEndCap>"
-				"<LineColor r='20' g='128' b='240'></LineColor>"
 				"<LineDashColor r='158' g='11' b='15'></LineDashColor>"
 				"<LinePassabilityClass>default</LinePassabilityClass>"
 			"</a:example>"
@@ -153,17 +153,6 @@ public:
 			"<element name='LineThickness' a:help='Thickness of the marker line connecting the entity to the rally point marker'>"
 				"<data type='decimal'/>"
 			"</element>"
-			"<element name='LineColor'>"
-				"<attribute name='r'>"
-					"<data type='integer'><param name='minInclusive'>0</param><param name='maxInclusive'>255</param></data>"
-				"</attribute>"
-				"<attribute name='g'>"
-					"<data type='integer'><param name='minInclusive'>0</param><param name='maxInclusive'>255</param></data>"
-				"</attribute>"
-				"<attribute name='b'>"
-					"<data type='integer'><param name='minInclusive'>0</param><param name='maxInclusive'>255</param></data>"
-				"</attribute>"
-			"</element>"
 			"<element name='LineDashColor'>"
 				"<attribute name='r'>"
 					"<data type='integer'><param name='minInclusive'>0</param><param name='maxInclusive'>255</param></data>"
@@ -210,12 +199,25 @@ public:
 	virtual void Deserialize(const CParamNode& paramNode, IDeserializer& UNUSED(deserialize))
 	{
 		Init(paramNode);
+		// The dependent components have not been deserialized, so the color is loaded on first SetDisplayed
 	}
 
 	virtual void HandleMessage(const CMessage& msg, bool UNUSED(global))
 	{
 		switch (msg.GetType())
 		{
+		case MT_PlayerColorChanged:
+			{
+				const CMessagePlayerColorChanged& msgData = static_cast<const CMessagePlayerColorChanged&> (msg);
+
+				CmpPtr<ICmpOwnership> cmpOwnership(GetEntityHandle());
+				if (!cmpOwnership || msgData.player != cmpOwnership->GetOwner())
+					break;
+
+				UpdateLineColor();
+				ConstructAllOverlayLines();
+			}
+			break;
 		case MT_RenderSubmit:
 			{
 				PROFILE("RallyPoint::RenderSubmit");
@@ -228,7 +230,18 @@ public:
 			break;
 		case MT_OwnershipChanged:
 			{
-				UpdateMarkers(); // update marker variation to new player's civilization
+				const CMessageOwnershipChanged& msgData = static_cast<const CMessageOwnershipChanged&> (msg);
+
+				// Ignore destroyed entities
+				if (msgData.to == INVALID_PLAYER)
+					break;
+
+				// Required for both the initial and capturing players color
+				UpdateLineColor();
+
+				// Support capturing, even though RallyPoint is typically deleted then
+				UpdateMarkers();
+				ConstructAllOverlayLines();
 			}
 			break;
 		case MT_TurnStart:
@@ -304,6 +317,13 @@ public:
 		{
 			m_Displayed = displayed;
 
+			// Set color after all dependent components are deserialized
+			if (displayed && m_LineColor.r < 0)
+			{
+				UpdateLineColor();
+				ConstructAllOverlayLines();
+			}
+
 			// move the markers out of oblivion and back into the real world, or vice-versa
 			UpdateMarkers();
 
@@ -331,6 +351,12 @@ public:
 		return !m_RallyPoints.empty();
 	}
 
+	void UpdateColor()
+	{
+		UpdateLineColor();
+		ConstructAllOverlayLines();
+	}
+
 private:
 
 	/**
@@ -349,6 +375,11 @@ private:
 		UpdateMessageSubscriptions();
 	}
 
+	/**
+	* Helper function to set the line color to its owner's color.
+	*/
+	void UpdateLineColor();
+
 	/**
 	 * Repositions the rally point markers; moves them outside of the world (ie. hides them), or positions them at the currently
 	 * set rally points. Also updates the actor's variation according to the entity's current owning player's civilization.
@@ -451,19 +482,11 @@ void CCmpRallyPointRenderer::Init(const CParamNode& paramNode)
 	m_LastMarkerCount = 0;
 	m_EnableDebugNodeOverlay = false;
 
+	UpdateLineColor();
 	// ---------------------------------------------------------------------------------------------
 	// load some XML configuration data (schema guarantees that all these nodes are valid)
 
 	m_MarkerTemplate = paramNode.GetChild("MarkerTemplate").ToString();
-
-	const CParamNode& lineColor = paramNode.GetChild("LineColor");
-	m_LineColor = CColor(
-		lineColor.GetChild("@r").ToInt()/255.f,
-		lineColor.GetChild("@g").ToInt()/255.f,
-		lineColor.GetChild("@b").ToInt()/255.f,
-		1.f
-	);
-
 	const CParamNode& lineDashColor = paramNode.GetChild("LineDashColor");
 	m_LineDashColor = CColor(
 		lineDashColor.GetChild("@r").ToInt()/255.f,
@@ -562,6 +585,28 @@ void CCmpRallyPointRenderer::UpdateMarkers()
 	m_LastMarkerCount = m_RallyPoints.size() - 1;
 }
 
+
+void CCmpRallyPointRenderer::UpdateLineColor()
+{
+	CmpPtr<ICmpOwnership> cmpOwnership(GetEntityHandle());
+	if (!cmpOwnership)
+		return;
+
+	player_id_t owner = cmpOwnership->GetOwner();
+	if (owner == INVALID_PLAYER)
+		return;
+
+	CmpPtr<ICmpPlayerManager> cmpPlayerManager(GetSystemEntity());
+	if (!cmpPlayerManager)
+		return;
+
+	CmpPtr<ICmpPlayer> cmpPlayer(GetSimContext(), cmpPlayerManager->GetPlayerByID(owner));
+	if (!cmpPlayer)
+		return;
+
+	m_LineColor = cmpPlayer->GetDisplayedColor();
+}
+
 void CCmpRallyPointRenderer::RecomputeAllRallyPointPaths()
 {
 	m_Path.clear();
