@@ -1,4 +1,4 @@
-/* Copyright (C) 2017 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -1053,6 +1053,11 @@ public:
 		return GetEntitiesByMask(~3); // bit 0 for owner=-1 and bit 1 for gaia
 	}
 
+	virtual std::vector<entity_id_t> GetGaiaAndNonGaiaEntities() const
+	{
+		return GetEntitiesByMask(~1); // bit 0 for owner=-1
+	}
+
 	std::vector<entity_id_t> GetEntitiesByMask(u32 ownerMask) const
 	{
 		std::vector<entity_id_t> entities;
@@ -1096,14 +1101,13 @@ public:
 			if (!query.enabled)
 				continue;
 
-			CmpPtr<ICmpPosition> cmpSourcePosition(query.source);
-			if (!cmpSourcePosition || !cmpSourcePosition->IsInWorld())
-				continue;
-
 			results.clear();
-			results.reserve(query.lastMatch.size());
-			CFixedVector2D pos = cmpSourcePosition->GetPosition2D();
-			PerformQuery(query, results, pos);
+			CmpPtr<ICmpPosition> cmpSourcePosition(query.source);
+			if (cmpSourcePosition && cmpSourcePosition->IsInWorld())
+			{
+				results.reserve(query.lastMatch.size());
+				PerformQuery(query, results, cmpSourcePosition->GetPosition2D());
+			}
 
 			// Compute the changes vs the last match
 			added.clear();
@@ -1117,7 +1121,8 @@ public:
 			if (added.empty() && removed.empty())
 				continue;
 
-			std::stable_sort(added.begin(), added.end(), EntityDistanceOrdering(m_EntityData, cmpSourcePosition->GetPosition2D()));
+			if (cmpSourcePosition && cmpSourcePosition->IsInWorld())
+				std::stable_sort(added.begin(), added.end(), EntityDistanceOrdering(m_EntityData, cmpSourcePosition->GetPosition2D()));
 
 			messages.resize(messages.size() + 1);
 			std::pair<entity_id_t, CMessageRangeUpdate>& back = messages.back();
@@ -1125,7 +1130,7 @@ public:
 			back.second.tag = it->first;
 			back.second.added.swap(added);
 			back.second.removed.swap(removed);
-			it->second.lastMatch.swap(results);
+			query.lastMatch.swap(results);
 		}
 
 		CComponentManager& cmpMgr = GetSimContext().GetComponentManager();
