@@ -408,8 +408,8 @@ public:
 			const CMessageValueModification& msgData = static_cast<const CMessageValueModification&> (msg);
 			if (msgData.component != L"UnitMotion")
 				break;
+			FALLTHROUGH;
 		}
-		// fall-through
 		case MT_OwnershipChanged:
 		case MT_Deserialized:
 		{
@@ -1771,7 +1771,7 @@ void CCmpUnitMotion::RenderPath(const WaypointPath& path, std::vector<SOverlayLi
 	bool floating = false;
 	CmpPtr<ICmpPosition> cmpPosition(GetEntityHandle());
 	if (cmpPosition)
-		floating = cmpPosition->IsFloating();
+		floating = cmpPosition->CanFloat();
 
 	lines.clear();
 	std::vector<float> waypointCoords;
