@@ -1,4 +1,4 @@
-/* Copyright (C) 2015 Wildfire Games.
+/* Copyright (C) 2017 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -25,8 +25,7 @@
 #include "ps/Filesystem.h"
 
 BEGIN_INTERFACE_WRAPPER(AIManager)
-DEFINE_INTERFACE_METHOD_3("AddPlayer", void, ICmpAIManager, AddPlayer, std::wstring, player_id_t, uint8_t)
-DEFINE_INTERFACE_METHOD_1("SetRNGSeed", void, ICmpAIManager, SetRNGSeed, uint32_t)
+DEFINE_INTERFACE_METHOD_4("AddPlayer", void, ICmpAIManager, AddPlayer, std::wstring, player_id_t, uint8_t, std::wstring)
 DEFINE_INTERFACE_METHOD_0("TryLoadSharedComponent", void, ICmpAIManager, TryLoadSharedComponent)
 DEFINE_INTERFACE_METHOD_0("RunGamestateInit", void, ICmpAIManager, RunGamestateInit)
 END_INTERFACE_WRAPPER(AIManager)
@@ -38,7 +37,7 @@ struct GetAIsHelper
 {
 	NONCOPYABLE(GetAIsHelper);
 public:
-	GetAIsHelper(ScriptInterface& scriptInterface) :
+	GetAIsHelper(const ScriptInterface& scriptInterface) :
 		m_ScriptInterface(scriptInterface),
 		m_AIs(scriptInterface.GetJSRuntime())
 	{
@@ -78,10 +77,10 @@ public:
 	}
 
 	JS::PersistentRootedObject m_AIs;
-	ScriptInterface& m_ScriptInterface;
+	const ScriptInterface& m_ScriptInterface;
 };
 
-JS::Value ICmpAIManager::GetAIs(ScriptInterface& scriptInterface)
+JS::Value ICmpAIManager::GetAIs(const ScriptInterface& scriptInterface)
 {
 	GetAIsHelper helper(scriptInterface);
 	helper.Run();
