@@ -1,4 +1,4 @@
-/* Copyright (C) 2017 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -18,7 +18,6 @@
 #ifndef INCLUDED_ICMPSELECTABLE
 #define INCLUDED_ICMPSELECTABLE
 
-#include "ps/CStrIntern.h"
 #include "simulation2/system/Interface.h"
 
 struct CColor;
@@ -26,51 +25,19 @@ struct CColor;
 class ICmpSelectable : public IComponent
 {
 public:
-
-	enum EOverlayType {
-		/// A single textured quad overlay, intended for entities that move around much, like units (e.g. foot soldiers, etc).
-		DYNAMIC_QUAD,
-		/// A more complex textured line overlay, composed of several textured line segments. Intended for entities that do not
-		/// move often, such as buildings (structures).
-		STATIC_OUTLINE,
-	};
-
-	struct SOverlayDescriptor
-	{
-		EOverlayType m_Type;
-		CStrIntern m_QuadTexture;
-		CStrIntern m_QuadTextureMask;
-		CStrIntern m_LineTexture;
-		CStrIntern m_LineTextureMask;
-		float m_LineThickness;
-		int m_Radius;
-
-		SOverlayDescriptor() : m_LineThickness(0) { }
-	};
-
 	/**
 	 * Returns true if the entity is only selectable in Atlas editor, e.g. a decorative visual actor.
 	 */
 	virtual bool IsEditorOnly() const = 0;
 
 	/**
-	 * Set the selection highlight state.
+	 * Sets the selection highlight state.
 	 * The highlight is typically a circle/square overlay around the unit.
 	 * @param color color and alpha of the selection highlight. Set color.a = 0 to hide the highlight.
 	 * @param selected whether the entity is selected; affects desaturation for always visible highlights.
 	 */
 	virtual void SetSelectionHighlight(const CColor& color, bool selected) = 0;
 
-	/**
-	 * Add a range overlay to this entity, for example for an aura or attack.
-	 */
-	virtual void AddRangeOverlay(float radius, const std::string& texture, const std::string& textureMask, float thickness) = 0;
-
-	/**
-	 * Delete all range overlays.
-	 */
-	virtual void ResetRangeOverlays() = 0;
-
 	/**
 	 * Enables or disables rendering of an entity's selectable.
 	 * @param visible Whether the selectable should be visible.
@@ -87,7 +54,12 @@ public:
 	}
 
 	/**
-	 * Set the alpha of the selection highlight. Set to 0 to hide the highlight.
+	 * Updates the selection color to match the current owner.
+	 */
+	virtual void UpdateColor() = 0;
+
+	/**
+	 * Sets the alpha of the selection highlight. Set to 0 to hide the highlight.
 	 */
 	virtual void SetSelectionHighlightAlpha(float alpha) = 0;
 
