@@ -1,4 +1,4 @@
-/* Copyright (C) 2015 Wildfire Games.
+/* Copyright (C) 2017 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -24,19 +24,19 @@
 
 BEGIN_INTERFACE_WRAPPER(UnitMotion)
 DEFINE_INTERFACE_METHOD_4("MoveToPointRange", bool, ICmpUnitMotion, MoveToPointRange, entity_pos_t, entity_pos_t, entity_pos_t, entity_pos_t)
-DEFINE_INTERFACE_METHOD_4("IsInPointRange", bool, ICmpUnitMotion, IsInPointRange, entity_pos_t, entity_pos_t, entity_pos_t, entity_pos_t)
-DEFINE_INTERFACE_METHOD_3("IsInTargetRange", bool, ICmpUnitMotion, IsInTargetRange, entity_id_t, entity_pos_t, entity_pos_t)
+DEFINE_INTERFACE_METHOD_CONST_4("IsInPointRange", bool, ICmpUnitMotion, IsInPointRange, entity_pos_t, entity_pos_t, entity_pos_t, entity_pos_t)
+DEFINE_INTERFACE_METHOD_CONST_3("IsInTargetRange", bool, ICmpUnitMotion, IsInTargetRange, entity_id_t, entity_pos_t, entity_pos_t)
 DEFINE_INTERFACE_METHOD_3("MoveToTargetRange", bool, ICmpUnitMotion, MoveToTargetRange, entity_id_t, entity_pos_t, entity_pos_t)
 DEFINE_INTERFACE_METHOD_3("MoveToFormationOffset", void, ICmpUnitMotion, MoveToFormationOffset, entity_id_t, entity_pos_t, entity_pos_t)
 DEFINE_INTERFACE_METHOD_2("FaceTowardsPoint", void, ICmpUnitMotion, FaceTowardsPoint, entity_pos_t, entity_pos_t)
 DEFINE_INTERFACE_METHOD_0("StopMoving", void, ICmpUnitMotion, StopMoving)
-DEFINE_INTERFACE_METHOD_0("GetCurrentSpeed", fixed, ICmpUnitMotion, GetCurrentSpeed)
+DEFINE_INTERFACE_METHOD_CONST_0("GetCurrentSpeed", fixed, ICmpUnitMotion, GetCurrentSpeed)
 DEFINE_INTERFACE_METHOD_1("SetSpeed", void, ICmpUnitMotion, SetSpeed, fixed)
-DEFINE_INTERFACE_METHOD_0("IsMoving", bool, ICmpUnitMotion, IsMoving)
-DEFINE_INTERFACE_METHOD_0("GetWalkSpeed", fixed, ICmpUnitMotion, GetWalkSpeed)
-DEFINE_INTERFACE_METHOD_0("GetRunSpeed", fixed, ICmpUnitMotion, GetRunSpeed)
-DEFINE_INTERFACE_METHOD_0("GetPassabilityClassName", std::string, ICmpUnitMotion, GetPassabilityClassName)
-DEFINE_INTERFACE_METHOD_0("GetUnitClearance", entity_pos_t, ICmpUnitMotion, GetUnitClearance)
+DEFINE_INTERFACE_METHOD_CONST_0("IsMoving", bool, ICmpUnitMotion, IsMoving)
+DEFINE_INTERFACE_METHOD_CONST_0("GetWalkSpeed", fixed, ICmpUnitMotion, GetWalkSpeed)
+DEFINE_INTERFACE_METHOD_CONST_0("GetRunSpeed", fixed, ICmpUnitMotion, GetRunSpeed)
+DEFINE_INTERFACE_METHOD_CONST_0("GetPassabilityClassName", std::string, ICmpUnitMotion, GetPassabilityClassName)
+DEFINE_INTERFACE_METHOD_CONST_0("GetUnitClearance", entity_pos_t, ICmpUnitMotion, GetUnitClearance)
 DEFINE_INTERFACE_METHOD_1("SetFacePointAfterMove", void, ICmpUnitMotion, SetFacePointAfterMove, bool)
 DEFINE_INTERFACE_METHOD_1("SetDebugOverlay", void, ICmpUnitMotion, SetDebugOverlay, bool)
 END_INTERFACE_WRAPPER(UnitMotion)
@@ -51,12 +51,12 @@ public:
 		return m_Script.Call<bool>("MoveToPointRange", x, z, minRange, maxRange);
 	}
 
-	virtual bool IsInPointRange(entity_pos_t x, entity_pos_t z, entity_pos_t minRange, entity_pos_t maxRange)
+	virtual bool IsInPointRange(entity_pos_t x, entity_pos_t z, entity_pos_t minRange, entity_pos_t maxRange) const
 	{
 		return m_Script.Call<bool>("IsInPointRange", x, z, minRange, maxRange);
 	}
 
-	virtual bool IsInTargetRange(entity_id_t target, entity_pos_t minRange, entity_pos_t maxRange)
+	virtual bool IsInTargetRange(entity_id_t target, entity_pos_t minRange, entity_pos_t maxRange) const
 	{
 		return m_Script.Call<bool>("IsInTargetRange", target, minRange, maxRange);
 	}
@@ -81,7 +81,7 @@ public:
 		m_Script.CallVoid("StopMoving");
 	}
 
-	virtual fixed GetCurrentSpeed()
+	virtual fixed GetCurrentSpeed() const
 	{
 		return m_Script.Call<fixed>("GetCurrentSpeed");
 	}
@@ -91,17 +91,17 @@ public:
 		m_Script.CallVoid("SetSpeed", speed);
 	}
 
-	virtual bool IsMoving()
+	virtual bool IsMoving() const
 	{
 		return m_Script.Call<bool>("IsMoving");
 	}
 
-	virtual fixed GetWalkSpeed()
+	virtual fixed GetWalkSpeed() const
 	{
 		return m_Script.Call<fixed>("GetWalkSpeed");
 	}
 
-	virtual fixed GetRunSpeed()
+	virtual fixed GetRunSpeed() const
 	{
 		return m_Script.Call<fixed>("GetRunSpeed");
 	}
@@ -111,17 +111,17 @@ public:
 		m_Script.CallVoid("SetFacePointAfterMove", facePointAfterMove);
 	}
 
-	virtual pass_class_t GetPassabilityClass()
+	virtual pass_class_t GetPassabilityClass() const
 	{
 		return m_Script.Call<pass_class_t>("GetPassabilityClass");
 	}
 
-	virtual std::string GetPassabilityClassName()
+	virtual std::string GetPassabilityClassName() const
 	{
 		return m_Script.Call<std::string>("GetPassabilityClassName");
 	}
 
-	virtual entity_pos_t GetUnitClearance()
+	virtual entity_pos_t GetUnitClearance() const
 	{
 		return m_Script.Call<entity_pos_t>("GetUnitClearance");
 	}
