@@ -1,4 +1,4 @@
-/* Copyright (C) 2017 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -24,6 +24,7 @@
 #include "maths/BoundingBoxOriented.h"
 #include "maths/BoundingBoxAligned.h"
 #include "maths/Fixed.h"
+#include "maths/FixedVector3D.h"
 #include "lib/file/vfs/vfs_path.h"
 
 class CUnit;
@@ -68,9 +69,10 @@ public:
 	/**
 	 * Return the exact position where a projectile should be launched from (based on the actor's
 	 * ammo prop points).
+	 * Return type is CFixedVector3D because it is exposed to the JS interface.
 	 * Returns (0,0,0) if no point can be found.
 	 */
-	virtual CVector3D GetProjectileLaunchPoint() const = 0;
+	virtual CFixedVector3D GetProjectileLaunchPoint() const = 0;
 
 	/**
 	 * Returns the underlying unit of this visual actor. May return NULL to indicate that no unit exists (e.g. may happen if the
@@ -101,7 +103,7 @@ public:
 	 * @param speed animation speed multiplier (typically 1.0 for the default speed)
 	 * @param soundgroup VFS path of sound group .xml, relative to audio/, or empty string for none
 	 */
-	virtual void SelectAnimation(const std::string& name, bool once, fixed speed, const std::wstring& soundgroup) = 0;
+	virtual void SelectAnimation(const std::string& name, bool once, fixed speed) = 0;
 
 	/**
 	 * Replaces a specified animation with another. Only affects the special speed-based
