@@ -1,4 +1,4 @@
-/* Copyright (C) 2016 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -34,7 +34,7 @@ class TestCmpPathfinder : public CxxTest::TestSuite
 public:
 	void setUp()
 	{
-		g_VFS = CreateVfs(20 * MiB);
+		g_VFS = CreateVfs();
 		g_VFS->Mount(L"", DataDir()/"mods"/"mod", VFS_MOUNT_MUST_EXIST);
 		g_VFS->Mount(L"", DataDir()/"mods"/"public", VFS_MOUNT_MUST_EXIST, 1); // ignore directory-not-found errors
 		TS_ASSERT_OK(g_VFS->Mount(L"cache", DataDir()/"_testcache"));
@@ -64,6 +64,53 @@ public:
 		TS_ASSERT_EQUALS((Pathfinding::NAVCELL_SIZE >> 1).ToInt_RoundToZero(), Pathfinding::NAVCELL_SIZE_LOG2);
 	}
 
+	void test_pathgoal()
+	{
+		entity_pos_t i = Pathfinding::NAVCELL_SIZE;
+		CFixedVector2D u(i*1, i*0);
+		CFixedVector2D v(i*0, i*1);
+
+		{
+			PathGoal goal = { PathGoal::POINT, i*8, i*6 };
+			TS_ASSERT_EQUALS(goal.NearestPointOnGoal(u*8 + v*4), u*8 + v*6);
+			TS_ASSERT_EQUALS(goal.DistanceToPoint(u*8 + v*4), i*2);
+			TS_ASSERT_EQUALS(goal.NearestPointOnGoal(u*0 + v*0), u*8 + v*6);
+			TS_ASSERT_EQUALS(goal.DistanceToPoint(u*0 + v*0), i*10);
+		}
+
+		{
+			PathGoal goal = { PathGoal::CIRCLE, i*8, i*6, i*5 };
+			TS_ASSERT_EQUALS(goal.NearestPointOnGoal(u*8 + v*4), u*8 + v*4);
+			TS_ASSERT_EQUALS(goal.DistanceToPoint(u*8 + v*4), i*0);
+			TS_ASSERT_EQUALS(goal.NearestPointOnGoal(u*0 + v*0), u*4 + v*3);
+			TS_ASSERT_EQUALS(goal.DistanceToPoint(u*0 + v*0), i*5);
+		}
+
+		{
+			PathGoal goal = { PathGoal::INVERTED_CIRCLE, i*8, i*6, i*5 };
+			TS_ASSERT_EQUALS(goal.NearestPointOnGoal(u*8 + v*4), u*8 + v*1);
+			TS_ASSERT_EQUALS(goal.DistanceToPoint(u*8 + v*4), i*3);
+			TS_ASSERT_EQUALS(goal.NearestPointOnGoal(u*0 + v*0), u*0 + v*0);
+			TS_ASSERT_EQUALS(goal.DistanceToPoint(u*0 + v*0), i*0);
+		}
+
+		{
+			PathGoal goal = { PathGoal::SQUARE, i*8, i*6, i*4, i*3, u, v };
+			TS_ASSERT_EQUALS(goal.NearestPointOnGoal(u*8 + v*4), u*8 + v*4);
+			TS_ASSERT_EQUALS(goal.DistanceToPoint(u*8 + v*4), i*0);
+			TS_ASSERT_EQUALS(goal.NearestPointOnGoal(u*0 + v*0), u*4 + v*3);
+			TS_ASSERT_EQUALS(goal.DistanceToPoint(u*0 + v*0), i*5);
+		}
+
+		{
+			PathGoal goal = { PathGoal::INVERTED_SQUARE, i*8, i*6, i*4, i*3, u, v };
+			TS_ASSERT_EQUALS(goal.NearestPointOnGoal(u*8 + v*4), u*8 + v*3);
+			TS_ASSERT_EQUALS(goal.DistanceToPoint(u*8 + v*4), i*1);
+			TS_ASSERT_EQUALS(goal.NearestPointOnGoal(u*0 + v*0), u*0 + v*0);
+			TS_ASSERT_EQUALS(goal.DistanceToPoint(u*0 + v*0), i*0);
+		}
+	}
+
 	void test_performance_DISABLED()
 	{
 		CTerrain terrain;
@@ -72,7 +119,7 @@ public:
 		sim2.LoadDefaultScripts();
 		sim2.ResetState();
 
-		CMapReader* mapReader = new CMapReader(); // it'll call "delete this" itself
+		std::unique_ptr<CMapReader> mapReader(new CMapReader());
 
 		LDR_BeginRegistering();
 		mapReader->LoadMap(L"maps/skirmishes/Median Oasis (2).pmp",
@@ -183,7 +230,7 @@ public:
 		sim2.LoadDefaultScripts();
 		sim2.ResetState();
 
-		CMapReader* mapReader = new CMapReader(); // it'll call "delete this" itself
+		std::unique_ptr<CMapReader> mapReader(new CMapReader());
 
 		LDR_BeginRegistering();
 		mapReader->LoadMap(L"maps/scenarios/Peloponnese.pmp",
@@ -238,7 +285,7 @@ public:
 		sim2.LoadDefaultScripts();
 		sim2.ResetState();
 
-		CMapReader* mapReader = new CMapReader(); // it'll call "delete this" itself
+		std::unique_ptr<CMapReader> mapReader(new CMapReader());
 
 		LDR_BeginRegistering();
 		mapReader->LoadMap(L"maps/scenarios/Peloponnese.pmp",
