@@ -1,4 +1,4 @@
-/* Copyright (C) 2015 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -31,11 +31,6 @@ CFixedVector2D Geometry::GetHalfBoundingBox(const CFixedVector2D& u, const CFixe
 	);
 }
 
-float Geometry::ChordToCentralAngle(const float chordLength, const float radius)
-{
-	return acosf(1.f - SQR(chordLength)/(2.f*SQR(radius))); // cfr. law of cosines
-}
-
 fixed Geometry::DistanceToSquare(const CFixedVector2D& point, const CFixedVector2D& u, const CFixedVector2D& v, const CFixedVector2D& halfSize, bool countInsideAsZero)
 {
 	/*
@@ -322,3 +317,43 @@ bool Geometry::TestSquareSquare(
 
 	return true;
 }
+
+int Geometry::GetPerimeterDistance(int x_max, int y_max, int x, int y)
+{
+	if (x_max <= 0 || y_max <= 0)
+		return 0;
+
+	int quarter = x_max + y_max;
+	if (x == x_max && y >= 0)
+		return y;
+	if (y == y_max)
+		return quarter - x;
+	if (x == -x_max)
+		return 2 * quarter - y;
+	if (y == -y_max)
+		return 3 * quarter + x;
+	if (x == x_max)
+		return 4 * quarter + y;
+	return 0;
+}
+
+std::pair<int, int> Geometry::GetPerimeterCoordinates(int x_max, int y_max, int k)
+{
+	if (x_max <= 0 || y_max <= 0)
+		return std::pair<int, int>(0, 0);
+
+	int quarter = x_max + y_max;
+	k %= 4 * quarter;
+	if (k < 0)
+		k += 4 * quarter;
+
+	if (k < y_max)
+		return std::pair<int, int>(x_max, k);
+	if (k < quarter + x_max)
+		return std::pair<int, int>(quarter - k, y_max);
+	if (k < 2 * quarter + y_max)
+		return std::pair<int, int>(-x_max, 2 * quarter - k);
+	if (k < 3 * quarter + x_max)
+		return std::pair<int, int>(k - 3 * quarter, -y_max);
+	return std::pair<int, int>(x_max, k - 4 * quarter);
+}
