@@ -1,4 +1,4 @@
-/* Copyright (C) 2017 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -46,9 +46,8 @@ public:
 		reset();
 	}
 
-	Grid(const Grid& g)
+	Grid(const Grid& g) : m_W(0), m_H(0), m_Data(NULL), m_DirtyID(0)
 	{
-		m_Data = NULL;
 		*this = g;
 	}
 
@@ -103,6 +102,22 @@ public:
 		return m_W == 0 && m_H == 0;
 	}
 
+	bool any_set_in_square(int i0, int j0, int i1, int j1) const
+	{
+	#if GRID_BOUNDS_DEBUG
+		ENSURE(i0 >= 0 && j0 >= 0 && i1 <= m_W && j1 <= m_H);
+	#endif
+		for (int j = j0; j < j1; ++j)
+		{
+			int sum = 0;
+			for (int i = i0; i < i1; ++i)
+				sum += m_Data[j*m_W + i];
+			if (sum > 0)
+				return true;
+		}
+		return false;
+	}
+
 	void reset()
 	{
 		if (m_Data)
@@ -150,7 +165,7 @@ public:
 	template<typename U>
 	bool compare_sizes(const Grid<U>* g) const
 	{
-		return m_W == g->m_W && m_H == g->m_H;
+		return g && m_W == g->m_W && m_H == g->m_H;
 	}
 
 	u16 m_W, m_H;
