@@ -52,7 +52,7 @@
 		return NULL; \
 	}
 
-JS::Value CMessage::ToJSValCached(ScriptInterface& scriptInterface) const
+JS::Value CMessage::ToJSValCached(const ScriptInterface& scriptInterface) const
 {
 	if (!m_Cached)
 		m_Cached.reset(new JS::PersistentRootedValue(scriptInterface.GetJSRuntime(), ToJSVal(scriptInterface)));
@@ -62,13 +62,13 @@ JS::Value CMessage::ToJSValCached(ScriptInterface& scriptInterface) const
 
 ////////////////////////////////
 
-JS::Value CMessageTurnStart::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageTurnStart::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessageTurnStart::FromJSVal(ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
+CMessage* CMessageTurnStart::FromJSVal(const ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
 {
 	return new CMessageTurnStart();
 }
@@ -76,13 +76,13 @@ CMessage* CMessageTurnStart::FromJSVal(ScriptInterface& UNUSED(scriptInterface),
 ////////////////////////////////
 
 #define MESSAGE_1(name, t0, a0) \
-	JS::Value CMessage##name::ToJSVal(ScriptInterface& scriptInterface) const \
+	JS::Value CMessage##name::ToJSVal(const ScriptInterface& scriptInterface) const \
 	{ \
 		TOJSVAL_SETUP(); \
 		SET_MSG_PROPERTY(a0); \
 		return JS::ObjectValue(*obj); \
 	} \
-	CMessage* CMessage##name::FromJSVal(ScriptInterface& scriptInterface, JS::HandleValue val) \
+	CMessage* CMessage##name::FromJSVal(const ScriptInterface& scriptInterface, JS::HandleValue val) \
 	{ \
 		FROMJSVAL_SETUP(); \
 		GET_MSG_PROPERTY(t0, a0); \
@@ -96,7 +96,7 @@ MESSAGE_1(Update_Final, fixed, turnLength)
 
 ////////////////////////////////
 
-JS::Value CMessageInterpolate::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageInterpolate::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	SET_MSG_PROPERTY(deltaSimTime);
@@ -105,7 +105,7 @@ JS::Value CMessageInterpolate::ToJSVal(ScriptInterface& scriptInterface) const
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessageInterpolate::FromJSVal(ScriptInterface& scriptInterface, JS::HandleValue val)
+CMessage* CMessageInterpolate::FromJSVal(const ScriptInterface& scriptInterface, JS::HandleValue val)
 {
 	FROMJSVAL_SETUP();
 	GET_MSG_PROPERTY(float, deltaSimTime);
@@ -116,13 +116,13 @@ CMessage* CMessageInterpolate::FromJSVal(ScriptInterface& scriptInterface, JS::H
 
 ////////////////////////////////
 
-JS::Value CMessageRenderSubmit::ToJSVal(ScriptInterface& UNUSED(scriptInterface)) const
+JS::Value CMessageRenderSubmit::ToJSVal(const ScriptInterface& UNUSED(scriptInterface)) const
 {
 	LOGWARNING("CMessageRenderSubmit::ToJSVal not implemented");
 	return JS::UndefinedValue();
 }
 
-CMessage* CMessageRenderSubmit::FromJSVal(ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
+CMessage* CMessageRenderSubmit::FromJSVal(const ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
 {
 	LOGWARNING("CMessageRenderSubmit::FromJSVal not implemented");
 	return NULL;
@@ -130,13 +130,13 @@ CMessage* CMessageRenderSubmit::FromJSVal(ScriptInterface& UNUSED(scriptInterfac
 
 ////////////////////////////////
 
-JS::Value CMessageProgressiveLoad::ToJSVal(ScriptInterface& UNUSED(scriptInterface)) const
+JS::Value CMessageProgressiveLoad::ToJSVal(const ScriptInterface& UNUSED(scriptInterface)) const
 {
 	LOGWARNING("CMessageProgressiveLoad::ToJSVal not implemented");
 	return JS::UndefinedValue();
 }
 
-CMessage* CMessageProgressiveLoad::FromJSVal(ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
+CMessage* CMessageProgressiveLoad::FromJSVal(const ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
 {
 	LOGWARNING("CMessageProgressiveLoad::FromJSVal not implemented");
 	return NULL;
@@ -144,13 +144,13 @@ CMessage* CMessageProgressiveLoad::FromJSVal(ScriptInterface& UNUSED(scriptInter
 
 ////////////////////////////////
 
-JS::Value CMessageDeserialized::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageDeserialized::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessageDeserialized::FromJSVal(ScriptInterface& scriptInterface, JS::HandleValue val)
+CMessage* CMessageDeserialized::FromJSVal(const ScriptInterface& scriptInterface, JS::HandleValue val)
 {
 	FROMJSVAL_SETUP();
 	return new CMessageDeserialized();
@@ -158,14 +158,14 @@ CMessage* CMessageDeserialized::FromJSVal(ScriptInterface& scriptInterface, JS::
 
 ////////////////////////////////
 
-JS::Value CMessageCreate::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageCreate::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	SET_MSG_PROPERTY(entity);
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessageCreate::FromJSVal(ScriptInterface& scriptInterface, JS::HandleValue val)
+CMessage* CMessageCreate::FromJSVal(const ScriptInterface& scriptInterface, JS::HandleValue val)
 {
 	FROMJSVAL_SETUP();
 	GET_MSG_PROPERTY(entity_id_t, entity);
@@ -174,14 +174,14 @@ CMessage* CMessageCreate::FromJSVal(ScriptInterface& scriptInterface, JS::Handle
 
 ////////////////////////////////
 
-JS::Value CMessageDestroy::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageDestroy::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	SET_MSG_PROPERTY(entity);
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessageDestroy::FromJSVal(ScriptInterface& scriptInterface, JS::HandleValue val)
+CMessage* CMessageDestroy::FromJSVal(const ScriptInterface& scriptInterface, JS::HandleValue val)
 {
 	FROMJSVAL_SETUP();
 	GET_MSG_PROPERTY(entity_id_t, entity);
@@ -190,7 +190,7 @@ CMessage* CMessageDestroy::FromJSVal(ScriptInterface& scriptInterface, JS::Handl
 
 ////////////////////////////////
 
-JS::Value CMessageOwnershipChanged::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageOwnershipChanged::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	SET_MSG_PROPERTY(entity);
@@ -199,7 +199,7 @@ JS::Value CMessageOwnershipChanged::ToJSVal(ScriptInterface& scriptInterface) co
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessageOwnershipChanged::FromJSVal(ScriptInterface& scriptInterface, JS::HandleValue val)
+CMessage* CMessageOwnershipChanged::FromJSVal(const ScriptInterface& scriptInterface, JS::HandleValue val)
 {
 	FROMJSVAL_SETUP();
 	GET_MSG_PROPERTY(entity_id_t, entity);
@@ -210,7 +210,7 @@ CMessage* CMessageOwnershipChanged::FromJSVal(ScriptInterface& scriptInterface,
 
 ////////////////////////////////
 
-JS::Value CMessagePositionChanged::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessagePositionChanged::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	SET_MSG_PROPERTY(entity);
@@ -221,7 +221,7 @@ JS::Value CMessagePositionChanged::ToJSVal(ScriptInterface& scriptInterface) con
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessagePositionChanged::FromJSVal(ScriptInterface& scriptInterface, JS::HandleValue val)
+CMessage* CMessagePositionChanged::FromJSVal(const ScriptInterface& scriptInterface, JS::HandleValue val)
 {
 	FROMJSVAL_SETUP();
 	GET_MSG_PROPERTY(entity_id_t, entity);
@@ -234,13 +234,13 @@ CMessage* CMessagePositionChanged::FromJSVal(ScriptInterface& scriptInterface, J
 
 ////////////////////////////////
 
-JS::Value CMessageInterpolatedPositionChanged::ToJSVal(ScriptInterface& UNUSED(scriptInterface)) const
+JS::Value CMessageInterpolatedPositionChanged::ToJSVal(const ScriptInterface& UNUSED(scriptInterface)) const
 {
 	LOGWARNING("CMessageInterpolatedPositionChanged::ToJSVal not implemented");
 	return JS::UndefinedValue();
 }
 
-CMessage* CMessageInterpolatedPositionChanged::FromJSVal(ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
+CMessage* CMessageInterpolatedPositionChanged::FromJSVal(const ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
 {
 	LOGWARNING("CMessageInterpolatedPositionChanged::FromJSVal not implemented");
 	return NULL;
@@ -248,7 +248,7 @@ CMessage* CMessageInterpolatedPositionChanged::FromJSVal(ScriptInterface& UNUSED
 
 ////////////////////////////////
 
-JS::Value CMessageTerritoryPositionChanged::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageTerritoryPositionChanged::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	SET_MSG_PROPERTY(entity);
@@ -256,7 +256,7 @@ JS::Value CMessageTerritoryPositionChanged::ToJSVal(ScriptInterface& scriptInter
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessageTerritoryPositionChanged::FromJSVal(ScriptInterface& scriptInterface, JS::HandleValue val)
+CMessage* CMessageTerritoryPositionChanged::FromJSVal(const ScriptInterface& scriptInterface, JS::HandleValue val)
 {
 	FROMJSVAL_SETUP();
 	GET_MSG_PROPERTY(entity_id_t, entity);
@@ -266,7 +266,7 @@ CMessage* CMessageTerritoryPositionChanged::FromJSVal(ScriptInterface& scriptInt
 
 ////////////////////////////////
 
-JS::Value CMessageMotionChanged::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageMotionChanged::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	SET_MSG_PROPERTY(starting);
@@ -274,7 +274,7 @@ JS::Value CMessageMotionChanged::ToJSVal(ScriptInterface& scriptInterface) const
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessageMotionChanged::FromJSVal(ScriptInterface& scriptInterface, JS::HandleValue val)
+CMessage* CMessageMotionChanged::FromJSVal(const ScriptInterface& scriptInterface, JS::HandleValue val)
 {
 	FROMJSVAL_SETUP();
 	GET_MSG_PROPERTY(bool, starting);
@@ -284,7 +284,7 @@ CMessage* CMessageMotionChanged::FromJSVal(ScriptInterface& scriptInterface, JS:
 
 ////////////////////////////////
 
-JS::Value CMessageTerrainChanged::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageTerrainChanged::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	SET_MSG_PROPERTY(i0);
@@ -294,7 +294,7 @@ JS::Value CMessageTerrainChanged::ToJSVal(ScriptInterface& scriptInterface) cons
 	return OBJECT_TO_JSVAL(obj);
 }
 
-CMessage* CMessageTerrainChanged::FromJSVal(ScriptInterface& scriptInterface, JS::HandleValue val)
+CMessage* CMessageTerrainChanged::FromJSVal(const ScriptInterface& scriptInterface, JS::HandleValue val)
 {
 	FROMJSVAL_SETUP();
 	GET_MSG_PROPERTY(int32_t, i0);
@@ -306,7 +306,7 @@ CMessage* CMessageTerrainChanged::FromJSVal(ScriptInterface& scriptInterface, JS
 
 ////////////////////////////////
 
-JS::Value CMessageVisibilityChanged::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageVisibilityChanged::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	SET_MSG_PROPERTY(player);
@@ -316,7 +316,7 @@ JS::Value CMessageVisibilityChanged::ToJSVal(ScriptInterface& scriptInterface) c
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessageVisibilityChanged::FromJSVal(ScriptInterface& scriptInterface, JS::HandleValue val)
+CMessage* CMessageVisibilityChanged::FromJSVal(const ScriptInterface& scriptInterface, JS::HandleValue val)
 {
 	FROMJSVAL_SETUP();
 	GET_MSG_PROPERTY(player_id_t, player);
@@ -328,46 +328,46 @@ CMessage* CMessageVisibilityChanged::FromJSVal(ScriptInterface& scriptInterface,
 
 ////////////////////////////////
 
-JS::Value CMessageWaterChanged::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageWaterChanged::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	return OBJECT_TO_JSVAL(obj);
 }
 
-CMessage* CMessageWaterChanged::FromJSVal(ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
+CMessage* CMessageWaterChanged::FromJSVal(const ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
 {
 	return new CMessageWaterChanged();
 }
 
 ////////////////////////////////
 
-JS::Value CMessageObstructionMapShapeChanged::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageObstructionMapShapeChanged::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessageObstructionMapShapeChanged::FromJSVal(ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
+CMessage* CMessageObstructionMapShapeChanged::FromJSVal(const ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
 {
 	return new CMessageObstructionMapShapeChanged();
 }
 
 ////////////////////////////////
 
-JS::Value CMessageTerritoriesChanged::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageTerritoriesChanged::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessageTerritoriesChanged::FromJSVal(ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
+CMessage* CMessageTerritoriesChanged::FromJSVal(const ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
 {
 	return new CMessageTerritoriesChanged();
 }
 
 ////////////////////////////////
 
-JS::Value CMessageRangeUpdate::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageRangeUpdate::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	SET_MSG_PROPERTY(tag);
@@ -376,7 +376,7 @@ JS::Value CMessageRangeUpdate::ToJSVal(ScriptInterface& scriptInterface) const
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessageRangeUpdate::FromJSVal(ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
+CMessage* CMessageRangeUpdate::FromJSVal(const ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
 {
 	LOGWARNING("CMessageRangeUpdate::FromJSVal not implemented");
 	return NULL;
@@ -384,13 +384,13 @@ CMessage* CMessageRangeUpdate::FromJSVal(ScriptInterface& UNUSED(scriptInterface
 
 ////////////////////////////////
 
-JS::Value CMessagePathResult::ToJSVal(ScriptInterface& UNUSED(scriptInterface)) const
+JS::Value CMessagePathResult::ToJSVal(const ScriptInterface& UNUSED(scriptInterface)) const
 {
 	LOGWARNING("CMessagePathResult::ToJSVal not implemented");
 	return JS::UndefinedValue();
 }
 
-CMessage* CMessagePathResult::FromJSVal(ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
+CMessage* CMessagePathResult::FromJSVal(const ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
 {
 	LOGWARNING("CMessagePathResult::FromJSVal not implemented");
 	return NULL;
@@ -398,7 +398,7 @@ CMessage* CMessagePathResult::FromJSVal(ScriptInterface& UNUSED(scriptInterface)
 
 ////////////////////////////////
 
-JS::Value CMessageValueModification::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageValueModification::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	SET_MSG_PROPERTY(entities);
@@ -407,7 +407,7 @@ JS::Value CMessageValueModification::ToJSVal(ScriptInterface& scriptInterface) c
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessageValueModification::FromJSVal(ScriptInterface& scriptInterface, JS::HandleValue val)
+CMessage* CMessageValueModification::FromJSVal(const ScriptInterface& scriptInterface, JS::HandleValue val)
 {
 	FROMJSVAL_SETUP();
 	GET_MSG_PROPERTY(std::vector<entity_id_t>, entities);
@@ -418,7 +418,7 @@ CMessage* CMessageValueModification::FromJSVal(ScriptInterface& scriptInterface,
 
 ////////////////////////////////
 
-JS::Value CMessageTemplateModification::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageTemplateModification::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	SET_MSG_PROPERTY(player);
@@ -427,7 +427,7 @@ JS::Value CMessageTemplateModification::ToJSVal(ScriptInterface& scriptInterface
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessageTemplateModification::FromJSVal(ScriptInterface& scriptInterface, JS::HandleValue val)
+CMessage* CMessageTemplateModification::FromJSVal(const ScriptInterface& scriptInterface, JS::HandleValue val)
 {
 	FROMJSVAL_SETUP();
 	GET_MSG_PROPERTY(player_id_t, player);
@@ -438,7 +438,7 @@ CMessage* CMessageTemplateModification::FromJSVal(ScriptInterface& scriptInterfa
 
 ////////////////////////////////
 
-JS::Value CMessageVisionRangeChanged::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageVisionRangeChanged::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	SET_MSG_PROPERTY(entity);
@@ -447,7 +447,7 @@ JS::Value CMessageVisionRangeChanged::ToJSVal(ScriptInterface& scriptInterface)
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessageVisionRangeChanged::FromJSVal(ScriptInterface& scriptInterface, JS::HandleValue val)
+CMessage* CMessageVisionRangeChanged::FromJSVal(const ScriptInterface& scriptInterface, JS::HandleValue val)
 {
 	FROMJSVAL_SETUP();
 	GET_MSG_PROPERTY(entity_id_t, entity);
@@ -456,7 +456,7 @@ CMessage* CMessageVisionRangeChanged::FromJSVal(ScriptInterface& scriptInterface
 	return new CMessageVisionRangeChanged(entity, oldRange, newRange);
 }
 
-JS::Value CMessageVisionSharingChanged::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageVisionSharingChanged::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	SET_MSG_PROPERTY(entity);
@@ -465,7 +465,7 @@ JS::Value CMessageVisionSharingChanged::ToJSVal(ScriptInterface& scriptInterface
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessageVisionSharingChanged::FromJSVal(ScriptInterface& scriptInterface, JS::HandleValue val)
+CMessage* CMessageVisionSharingChanged::FromJSVal(const ScriptInterface& scriptInterface, JS::HandleValue val)
 {
 	FROMJSVAL_SETUP();
 	GET_MSG_PROPERTY(entity_id_t, entity);
@@ -476,27 +476,27 @@ CMessage* CMessageVisionSharingChanged::FromJSVal(ScriptInterface& scriptInterfa
 
 ////////////////////////////////
 
-JS::Value CMessageMinimapPing::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageMinimapPing::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessageMinimapPing::FromJSVal(ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
+CMessage* CMessageMinimapPing::FromJSVal(const ScriptInterface& UNUSED(scriptInterface), JS::HandleValue UNUSED(val))
 {
 	return new CMessageMinimapPing();
 }
 
 ////////////////////////////////
 
-JS::Value CMessageCinemaPathEnded::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageCinemaPathEnded::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	SET_MSG_PROPERTY(name);
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessageCinemaPathEnded::FromJSVal(ScriptInterface& scriptInterface, JS::HandleValue val)
+CMessage* CMessageCinemaPathEnded::FromJSVal(const ScriptInterface& scriptInterface, JS::HandleValue val)
 {
 	FROMJSVAL_SETUP();
 	GET_MSG_PROPERTY(CStrW, name);
@@ -505,13 +505,13 @@ CMessage* CMessageCinemaPathEnded::FromJSVal(ScriptInterface& scriptInterface, J
 
 ////////////////////////////////
 
-JS::Value CMessageCinemaQueueEnded::ToJSVal(ScriptInterface& scriptInterface) const
+JS::Value CMessageCinemaQueueEnded::ToJSVal(const ScriptInterface& scriptInterface) const
 {
 	TOJSVAL_SETUP();
 	return JS::ObjectValue(*obj);
 }
 
-CMessage* CMessageCinemaQueueEnded::FromJSVal(ScriptInterface& scriptInterface, JS::HandleValue val)
+CMessage* CMessageCinemaQueueEnded::FromJSVal(const ScriptInterface& scriptInterface, JS::HandleValue val)
 {
 	FROMJSVAL_SETUP();
 	return new CMessageCinemaQueueEnded();
@@ -519,7 +519,23 @@ CMessage* CMessageCinemaQueueEnded::FromJSVal(ScriptInterface& scriptInterface,
 
 ////////////////////////////////////////////////////////////////
 
-CMessage* CMessageFromJSVal(int mtid, ScriptInterface& scriptingInterface, JS::HandleValue val)
+JS::Value CMessagePlayerColorChanged::ToJSVal(const ScriptInterface& scriptInterface) const
+{
+	TOJSVAL_SETUP();
+	SET_MSG_PROPERTY(player);
+	return JS::ObjectValue(*obj);
+}
+
+CMessage* CMessagePlayerColorChanged::FromJSVal(const ScriptInterface& scriptInterface, JS::HandleValue val)
+{
+	FROMJSVAL_SETUP();
+	GET_MSG_PROPERTY(player_id_t, player);
+	return new CMessagePlayerColorChanged(player);
+}
+
+////////////////////////////////////////////////////////////////
+
+CMessage* CMessageFromJSVal(int mtid, const ScriptInterface& scriptingInterface, JS::HandleValue val)
 {
 	switch (mtid)
 	{
