@@ -1,4 +1,4 @@
-/* Copyright (C) 2015 Wildfire Games.
+/* Copyright (C) 2017 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -59,7 +59,7 @@ private:
 class CStdSerializer : public CBinarySerializer<CStdSerializerImpl>
 {
 public:
-	CStdSerializer(ScriptInterface& scriptInterface, std::ostream& stream);
+	CStdSerializer(const ScriptInterface& scriptInterface, std::ostream& stream);
 
 	virtual std::ostream& GetStream();
 };
