@@ -1,4 +1,4 @@
-/* Copyright (C) 2015 Wildfire Games.
+/* Copyright (C) 2017 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -76,6 +76,8 @@ void CParamNode::ApplyLayer(const XMBFile& xmb, const XMBElement& element, const
 	// Look for special attributes
 	int at_disable = xmb.GetAttributeID("disable");
 	int at_replace = xmb.GetAttributeID("replace");
+	int at_filtered = xmb.GetAttributeID("filtered");
+	int at_merge = xmb.GetAttributeID("merge");
 	int at_op = xmb.GetAttributeID("op");
 	int at_datatype = xmb.GetAttributeID("datatype");
 	enum op {
@@ -84,6 +86,8 @@ void CParamNode::ApplyLayer(const XMBFile& xmb, const XMBElement& element, const
 		MUL
 	} op = INVALID;
 	bool replacing = false;
+	bool filtering = false;
+	bool merging = false;
 	{
 		XERO_ITER_ATTR(element, attr)
 		{
@@ -97,14 +101,24 @@ void CParamNode::ApplyLayer(const XMBFile& xmb, const XMBElement& element, const
 				m_Childs.erase(name);
 				replacing = true;
 			}
+			else if (attr.Name == at_filtered)
+			{
+				filtering = true;
+			}
+			else if (attr.Name == at_merge)
+			{
+				if (m_Childs.find(name) == m_Childs.end())
+					return;
+				merging = true;
+			}
 			else if (attr.Name == at_op)
 			{
-				if (std::wstring(attr.Value.begin(), attr.Value.end()) == L"add") 
-					op = ADD; 
-				else if (std::wstring(attr.Value.begin(), attr.Value.end()) == L"mul") 
-					op = MUL; 
-				else 
-					LOGWARNING("Invalid op '%ls'", attr.Value); 
+				if (std::wstring(attr.Value.begin(), attr.Value.end()) == L"add")
+					op = ADD;
+				else if (std::wstring(attr.Value.begin(), attr.Value.end()) == L"mul")
+					op = MUL;
+				else
+					LOGWARNING("Invalid op '%ls'", attr.Value);
 			}
 		}
 	}
@@ -152,36 +166,54 @@ void CParamNode::ApplyLayer(const XMBFile& xmb, const XMBElement& element, const
 
 	// Add this element as a child node
 	CParamNode& node = m_Childs[name];
-	if (op != INVALID) 
-	{ 
+	if (op != INVALID)
+	{
 		// TODO: Support parsing of data types other than fixed; log warnings in other cases
 		fixed oldval = node.ToFixed();
 		fixed mod = fixed::FromString(CStrW(value));
-		switch (op) 
-		{ 
-		case ADD: 
-			node.m_Value = (oldval + mod).ToString().FromUTF8(); 
-			break; 
-		case MUL: 
-			node.m_Value = (oldval.Multiply(mod)).ToString().FromUTF8(); 
-			break; 
-		} 
-		hasSetValue = true; 
-	} 
-	if (!hasSetValue)
+
+		switch (op)
+		{
+		case ADD:
+			node.m_Value = (oldval + mod).ToString().FromUTF8();
+			break;
+		case MUL:
+			node.m_Value = (oldval.Multiply(mod)).ToString().FromUTF8();
+			break;
+		}
+		hasSetValue = true;
+	}
+
+	if (!hasSetValue && !merging)
 		node.m_Value = value;
 
+	// We also need to reset node's script val, even if it has no children
+	// or if the attributes change.
+	node.ResetScriptVal();
+
+	// For the filtered case
+	ChildrenMap childs;
+
 	// Recurse through the element's children
 	XERO_ITER_EL(element, child)
 	{
 		node.ApplyLayer(xmb, child, sourceIdentifier);
+		if (filtering)
+		{
+			std::string childname = xmb.GetElementString(child.GetNodeName());
+			if (node.m_Childs.find(childname) != node.m_Childs.end())
+				childs[childname] = std::move(node.m_Childs[childname]);
+		}
 	}
 
+	if (filtering)
+		node.m_Childs.swap(childs);
+
 	// Add the element's attributes, prefixing names with "@"
 	XERO_ITER_ATTR(element, attr)
 	{
 		// Skip special attributes
-		if (attr.Name == at_replace || attr.Name == at_op)
+		if (attr.Name == at_replace || attr.Name == at_op || attr.Name == at_merge || attr.Name == at_filtered)
 			continue;
 		// Add any others
 		std::string attrName = xmb.GetAttributeString(attr.Name);
@@ -189,21 +221,6 @@ void CParamNode::ApplyLayer(const XMBFile& xmb, const XMBElement& element, const
 	}
 }
 
-void CParamNode::CopyFilteredChildrenOfChild(const CParamNode& src, const char* name, const std::set<std::string>& permitted)
-{
-	ResetScriptVal();
-
-	ChildrenMap::iterator dstChild = m_Childs.find(name);
-	ChildrenMap::const_iterator srcChild = src.m_Childs.find(name);
-	if (dstChild == m_Childs.end() || srcChild == src.m_Childs.end())
-		return; // error
-
-	ChildrenMap::const_iterator it = srcChild->second.m_Childs.begin();
-	for (; it != srcChild->second.m_Childs.end(); ++it)
-		if (permitted.count(it->first))
-			dstChild->second.m_Childs[it->first] = it->second;
-}
-
 const CParamNode& CParamNode::GetChild(const char* name) const
 {
 	ChildrenMap::const_iterator it = m_Childs.find(name);
@@ -246,7 +263,7 @@ fixed CParamNode::ToFixed() const
 	return fixed::FromString(CStrW(m_Value));
 }
 
-float CParamNode::ToFloat() const 
+float CParamNode::ToFloat() const
 {
 	float ret = 0;
 	std::wstringstream strm;
