@@ -1,4 +1,4 @@
-/* Copyright (C) 2012 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -23,7 +23,7 @@ class ScriptInterface;
 
 namespace JSI_Sound
 {
-  void RegisterScriptFunctions(ScriptInterface& scriptInterface);
+	void RegisterScriptFunctions(const ScriptInterface& scriptInterface);
 }
 
-#endif  // #ifndef INCLUDED_SOUNDSCRIPTINTERFACE
+#endif // INCLUDED_SOUNDSCRIPTINTERFACE
