@@ -1,4 +1,4 @@
-/* Copyright (C) 2012 Wildfire Games.
+/* Copyright (C) 2017 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -25,7 +25,6 @@
 
 #include "ActorEditor/ActorEditor.h"
 #include "ScenarioEditor/ScenarioEditor.h"
-#include "ErrorReporter/ErrorReporter.h"
 
 #include "GameInterface/MessagePasser.h"
 
@@ -127,7 +126,7 @@ ATLASDLLIMPEXP void Atlas_StartWindow(const wchar_t* type)
 	// Initialise libxml2
 	// (If we're executed from the game instead, it has the responsibility to initialise libxml2)
 	LIBXML_TEST_VERSION
-	
+
 	g_InitialWindowType = type;
 #ifdef __WXMSW__
 	wxEntry(g_Module);
@@ -177,12 +176,6 @@ ATLASDLLIMPEXP void Atlas_DisplayError(const wchar_t* text, size_t WXUNUSED(flag
 	// this function is called
 }
 
-
-ATLASDLLIMPEXP void Atlas_ReportError()
-{
-	///ReportError();	// janwas: disabled until ErrorReporter.cpp compiles
-}
-
 class AtlasDLLApp : public wxApp
 {
 public:
