@@ -1,4 +1,4 @@
-/* Copyright (C) 2017 Wildfire Games.
+/* Copyright (C) 2018 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -238,10 +238,8 @@ void ActorViewerImpl::UpdatePropListRecursive(CModelAbstract* modelAbstract)
 	if (model)
 	{
 		std::vector<CModel::Prop>& modelProps = model->GetProps();
-		for (size_t i=0; i < modelProps.size(); i++)
+		for (CModel::Prop& modelProp : modelProps)
 		{
-			CModel::Prop& modelProp = modelProps[i];
-
 			Props.push_back(modelProp);
 			if (modelProp.m_Model)
 				UpdatePropListRecursive(modelProp.m_Model);
@@ -289,10 +287,14 @@ ActorViewer::ActorViewer()
 		debug_warn(L"Failed to load whiteness texture");
 	}
 
-	// Start the simulation
+	// Prepare the simulation
 	m.Simulation2.LoadDefaultScripts();
 	m.Simulation2.ResetState();
 
+	// Set player data
+	m.Simulation2.SetMapSettings(m.Simulation2.GetPlayerDefaults());
+	m.Simulation2.LoadPlayerSettings(true);
+
 	// Tell the simulation we've already loaded the terrain
 	CmpPtr<ICmpTerrain> cmpTerrain(m.Simulation2, SYSTEM_ENTITY);
 	if (cmpTerrain)
@@ -302,6 +304,8 @@ ActorViewer::ActorViewer()
 	CmpPtr<ICmpRangeManager> cmpRangeManager(m.Simulation2, SYSTEM_ENTITY);
 	if (cmpRangeManager)
 		cmpRangeManager->SetLosRevealAll(-1, true);
+
+	m.Simulation2.InitGame();
 }
 
 ActorViewer::~ActorViewer()
@@ -421,19 +425,11 @@ void ActorViewer::SetActor(const CStrW& name, const CStrW& animation, player_id_
 		else if (anim.Find("gather_") == 0)
 			sound = anim;
 
-		std::wstring soundgroup;
-		if (!sound.empty())
-		{
-			CStr code = "var cmp = Engine.QueryInterface("+CStr::FromUInt(m.Entity)+", IID_Sound); " +
-				"if (cmp) cmp.GetSoundGroup('"+sound+"'); else '';";
-			m.Simulation2.GetScriptInterface().Eval(code.c_str(), soundgroup);
-		}
-
 		CmpPtr<ICmpVisual> cmpVisual(m.Simulation2, m.Entity);
 		if (cmpVisual)
 		{
 			// TODO: SetEntitySelection(anim)
-			cmpVisual->SelectAnimation(anim, false, fixed::FromFloat(speed), soundgroup);
+			cmpVisual->SelectAnimation(anim, false, fixed::FromFloat(speed));
 			if (repeattime)
 				cmpVisual->SetAnimationSyncRepeat(fixed::FromFloat(repeattime));
 		}
