@@ -87,7 +87,7 @@ MESSAGEHANDLER(InitGraphics)
 
 	ogl_Init();
 
-	InitGraphics(g_AtlasGameLoop->args, g_InitFlags);
+	InitGraphics(g_AtlasGameLoop->args, g_InitFlags, {});
 
 #if OS_WIN
 	// HACK (to stop things looking very ugly when scrolling) - should
@@ -198,6 +198,7 @@ MESSAGEHANDLER(ResizeScreen)
 MESSAGEHANDLER(RenderStyle)
 {
 	g_Renderer.SetTerrainRenderMode(msg->wireframe ? EDGED_FACES : SOLID);
+	g_Renderer.SetWaterRenderMode(msg->wireframe ? EDGED_FACES : SOLID);
 	g_Renderer.SetModelRenderMode(msg->wireframe ? EDGED_FACES : SOLID);
 }
 
