@@ -18,7 +18,8 @@ class MozrunnerTestCase(unittest.TestCase):
         self.threads = [ ]
 
         self.profile = mozprofile.FirefoxProfile()
-        self.runner = mozrunner.FirefoxRunner(self.profile)
+        self.runner = mozrunner.FirefoxRunner(os.environ['BROWSER_PATH'],
+                                              profile=self.profile)
 
     def tearDown(self):
         for thread in self.threads:
